<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'moodle', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   core
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['abouttobeinstalled'] = 'about to be installed';
$string['accept'] = 'Accept';
$string['action'] = 'Action';
$string['actionchoice'] = 'What do you want to do with the file \'{$a}\'?';
$string['actions'] = 'Actions';
$string['actionsmenu'] = 'Actions menu';
$string['active'] = 'Active';
$string['activeusers'] = 'Active users';
$string['activities'] = 'Activities';
$string['activity'] = 'Activity';
$string['activityclipboard'] = 'Moving this activity: {$a}';
$string['activityicon'] = '{$a} icon';
$string['activityiscurrentlyhidden'] = 'Sorry, this activity is currently hidden';
$string['activityheader'] = 'Activity menu';
$string['activitymodule'] = 'Activity module';
$string['activitymodules'] = 'Activity modules';
$string['activitynotready'] = 'Activity not ready yet';
$string['activityorresource'] = 'Activity or resource';
$string['activityreport'] = 'Activity report';
$string['activityreports'] = 'Activity reports';
$string['activityselect'] = 'Select this activity to be moved elsewhere';
$string['activitysince'] = 'Activity since {$a}';
$string['activitytypetitle'] = '{$a->activity} - {$a->type}';
$string['activityweighted'] = 'Activity per user';
$string['actionsfor'] = 'Actions for {$a}';
$string['add'] = 'Add';
$string['addactivity'] = 'Add an activity...';
$string['addactivitytosection'] = 'Add an activity to section \'{$a}\'';
$string['addadmin'] = 'Add admin';
$string['addblock'] = 'Add a block';
$string['addcomment'] = 'Add a comment...';
$string['addcondition'] = 'Add condition';
$string['addcontent'] = 'Add content';
$string['addcountertousername'] = 'Create user by adding number to username';
$string['addcreator'] = 'Add course creator';
$string['adddots'] = 'Add...';
$string['added'] = 'Added {$a}';
$string['addedtogroup'] = 'Added to group "{$a}"';
$string['addedtogroupnot'] = 'Not added to group "{$a}"';
$string['addedtogroupnotenrolled'] = 'Not added to group "{$a}", because not enrolled in course';
$string['addfilehere'] = 'Drop files here to add them at the bottom of this section';
$string['addfilesdrop'] = 'You can drag and drop files here to upload or click to select.';
$string['addinganew'] = 'New {$a}';
$string['additionalcustomnav'] = 'Additional custom navigation';
$string['addnew'] = 'Add a new {$a}';
$string['addingdatatoexisting'] = 'Adding data to existing';
$string['additionalnames'] = 'Additional names';
$string['addlinkhere'] = 'Add link here';
$string['addnewcategory'] = 'Add new category';
$string['addnewcourse'] = 'Add a new course';
$string['addnewuser'] = 'Add a new user';
$string['addnousersrecip'] = 'Add users who haven\'t accessed this {$a} to recipient list';
$string['addpagehere'] = 'Add text here';
$string['addresource'] = 'Add a resource...';
$string['addresourceoractivity'] = 'Add an activity or resource';
$string['addresourcetosection'] = 'Add a resource to section \'{$a}\'';
$string['address'] = 'Address';
$string['addsections'] = 'Add sections';
$string['addstudent'] = 'Add student';
$string['addsubcategory'] = 'Add a subcategory';
$string['addteacher'] = 'Add teacher';
$string['admin'] = 'Admin';
$string['adminhelpaddnewuser'] = 'To manually create a new user account';
$string['adminhelpassignadmins'] = 'Admins can do anything and go anywhere in the site';
$string['adminhelpassigncreators'] = 'Course creators can create new courses';
$string['adminhelpassignsiteroles'] = 'Apply defined site roles to specific users';
$string['adminhelpassignstudents'] = 'Go into a course and add students from the admin menu';
$string['adminhelpauthentication'] = 'You can use internal user accounts or external databases';
$string['adminhelpbackup'] = 'Configure automated backups and their schedule';
$string['adminhelpconfiguration'] = 'Configure how the site looks and works';
$string['adminhelpconfigvariables'] = 'Configure variables that affect general operation of the site';
$string['adminhelpcourses'] = 'Define courses and categories and assign people to them, edit pending courses';
$string['adminhelpeditorsettings'] = 'Define basic settings for HTML editor';
$string['adminhelpedituser'] = 'Browse the list of user accounts and edit any of them';
$string['adminhelpenvironment'] = 'Check how your server suits current and future installation requirements';
$string['adminhelpfailurelogs'] = 'Browse logs of failed logins';
$string['adminhelplanguage'] = 'For checking and editing the current language pack';
$string['adminhelplogs'] = 'Browse logs of all activity on this site';
$string['adminhelpmanageblocks'] = 'Manage installed blocks and their settings';
$string['adminhelpmanagedatabase'] = 'Access the database directly (be careful!)';
$string['adminhelpmanagefilters'] = 'Choose text filters and related settings';
$string['adminhelpmanagemodules'] = 'Manage installed modules and their settings';
$string['adminhelpmanageroles'] = 'Create and define roles that may be applied to users';
$string['adminhelpmymoodle'] = 'Configure the My Moodle blocks for users';
$string['adminhelpreports'] = 'Site level reports';
$string['adminhelpsitefiles'] = 'For publishing general files or uploading external backups';
$string['adminhelpsitesettings'] = 'Define how the site home looks';
$string['adminhelpstickyblocks'] = 'Configure Moodle-wide sticky blocks';
$string['adminhelpthemes'] = 'Choose how the site looks (colours, fonts etc)';
$string['adminhelpuploadusers'] = 'Import new user accounts from a text file';
$string['adminhelpusers'] = 'Define your users and set up authentication';
$string['adminhelpxmldbeditor'] = 'Interface to edit the XMLDB files. Only for developers.';
$string['administration'] = 'Administration';
$string['administrationsite'] = 'Site administration';
$string['administrator'] = 'Administrator';
$string['administratordescription'] = 'Administrators can usually do anything on the site, in all courses.';
$string['administrators'] = 'Administrators';
$string['administratorsall'] = 'All administrators';
$string['administratorsandteachers'] = 'Administrators and teachers';
$string['advanced'] = 'Advanced';
$string['advancedfilter'] = 'Advanced search';
$string['advancedsettings'] = 'Advanced settings';
$string['afterresource'] = 'After resource "{$a}"';
$string['aftersection'] = 'After section "{$a}"';
$string['again'] = 'again';
$string['agelocationverification'] = 'Age and location verification';
$string['ajaxuse'] = 'AJAX and Javascript';
$string['all'] = 'All';
$string['allactions'] = 'All actions';
$string['allactivities'] = 'All activities';
$string['allcategories'] = 'All categories';
$string['alldays'] = 'All days';
$string['allfiles'] = 'All files';
$string['allgroups'] = 'All groups';
$string['allchanges'] = 'All changes';
$string['alllogs'] = 'All logs';
$string['allmods'] = 'All {$a}';
$string['allow'] = 'Allow';
$string['allowinternal'] = 'Allow internal methods as well';
$string['allowstealthmodules'] = 'Allow stealth activities';
$string['allowstealthmodules_help'] = 'If enabled, activities can be made available but not shown in visible sections of the course page. If so, links to stealth activities must be provided from elsewhere, such as from a page resource. Stealth activities are still listed in the gradebook and other reports.';
$string['allownone'] = 'Allow none';
$string['allownot'] = 'Do not allow';
$string['allparticipants'] = 'All participants';
$string['allteachers'] = 'All teachers';
$string['alphanumerical'] = 'Can only contain alphanumeric characters, hyphen (-) or period (.)';
$string['alreadyconfirmed'] = 'Registration has already been confirmed';
$string['alternatename'] = 'Alternate name';
$string['always'] = 'Always';
$string['and'] = '{$a->one} and {$a->two}';
$string['answer'] = 'Answer';
$string['any'] = 'Any';
$string['approve'] = 'Approve';
$string['appearance'] = 'Appearance';
$string['apply'] = 'Apply';
$string['applyfilters'] = 'Apply filters';
$string['areyousure'] = 'Are you sure?';
$string['areyousuretorestorethis'] = 'Do you want to continue?';
$string['areyousuretorestorethisinfo'] = 'Later in this process you will have a choice of adding this backup to an existing course or creating a completely new course.';
$string['asc'] = 'Ascending';
$string['assessment'] = 'Assessment';
$string['assignadmins'] = 'Assign admins';
$string['assigncreators'] = 'Assign creators';
$string['assignedrolecount'] = '{$a->role}: {$a->count}';
$string['assignsiteroles'] = 'Assign site-wide roles';
$string['authenticateduser'] = 'Authenticated user';
$string['authenticateduserdescription'] = 'All logged in users.';
$string['authentication'] = 'Authentication';
$string['authenticationplugins'] = 'Authentication plugins';
$string['autosubscribe'] = 'Forum auto-subscribe';
$string['autosubscribeno'] = 'No: don\'t automatically subscribe me to forum discussions';
$string['autosubscribeyes'] = 'Yes: when I post, subscribe me to that forum discussion';
$string['availability'] = 'Availability';
$string['availablecourses'] = 'Available courses';
$string['back'] = 'Back';
$string['backto'] = 'Back to {$a}';
$string['backtocourselisting'] = 'Back to course listing';
$string['backtohome'] = 'Back to the site home';
$string['backtopageyouwereon'] = 'Back to the page you were on';
$string['backup'] = 'Backup';
$string['backupactivehelp'] = 'Choose whether or not to do automated backups.';
$string['backupadhocpending'] = 'Course backup ad hoc task pending';
$string['backupcancelled'] = 'Backup cancelled';
$string['backupcoursefileshelp'] = 'If enabled then course files will be included in automated backups';
$string['backupdate'] = 'Backup date';
$string['backupdatenew'] = '&nbsp; {$a->TAG} is now {$a->weekday}, {$a->mday} {$a->month} {$a->year}<br />';
$string['backupdateold'] = '{$a->TAG} was {$a->weekday}, {$a->mday} {$a->month} {$a->year}';
$string['backupdaterecordtype'] = '<br />{$a->recordtype} - {$a->recordname}<br />';
$string['backupdetails'] = 'Backup details';
$string['backuperrorinvaliddestination'] = 'The backup destination folder does not exist or is not writable.';
$string['backupexecuteathelp'] = 'Choose what time automated backups should run at.';
$string['backupfailed'] = 'Some of your courses weren\'t saved.';
$string['backupfilename'] = 'backup';
$string['backupfinished'] = 'Backup completed successfully';
$string['backupfromthissite'] = 'Backup was made on this site?';
$string['backupgradebookhistoryhelp'] = 'If enabled then gradebook history will be included in automated backups. Note that grade history must not be disabled in server settings (disablegradehistory) in order for this to work';
$string['backupincludemoduleshelp'] = 'Choose whether you want to include course modules, with or without user data, in automated backups';
$string['backupincludemoduleuserdatahelp'] = 'Choose whether you want to include module user data in automated backups.';
$string['backupinfo'] = 'Make a copy of this course, including all content and activity to date. You can use the backup file to restore the course.';
$string['backuplogdetailed'] = 'Detailed execution log';
$string['backuploglaststatus'] = 'Last execution log';
$string['backupmissinguserinfoperms'] = 'Note: This backup contains no user data. Exercise and Workshop activities will not be included in the backup, since these modules are not compatible with this type of backup.';
$string['backupnext'] = 'Next backup';
$string['backupnonisowarning'] = 'Warning: this backup is from a non-Unicode version of Moodle (pre 1.6). If this backup contains any non-ISO-8859-1 texts then they may be CORRUPTED if you try to restore them to this Unicode version of Moodle. See the <a href="https://docs.moodle.org/en/Backup_FAQ">Backup FAQ</a> for more information about how to recover this backup correctly.';
$string['backupnotyetrun'] = 'Automated backup pending';
$string['backuporiginalname'] = 'Backup name';
$string['backuproleassignments'] = 'Backup role assignments for these roles';
$string['backupsavetohelp'] = 'Full path to the directory where you want to save the backup files';
$string['backupsitefileshelp'] = 'If enabled then site files used in courses will be included in automated backups';
$string['backuptakealook'] = 'Please take a look at your backup logs in:
  {$a}';
$string['backupuserfileshelp'] = 'Choose whether user files (eg profile images) should be included in automated backups';
$string['backupversion'] = 'Backup version';
$string['badges'] = 'Badges';
$string['between'] = 'Between';
$string['block'] = 'Block';
$string['blockconfiga'] = 'Configuring a {$a} block';
$string['blockconfigbad'] = 'This block has not been implemented correctly and thus cannot provide a configuration interface.';
$string['blocks'] = 'Blocks';
$string['blocks_main'] = 'Main content blocks';
$string['blocks_supplementary'] = 'Supplementary blocks';
$string['blocksaddedit'] = 'Add/Edit blocks';
$string['blockseditoff'] = 'Blocks editing off';
$string['blocksediton'] = 'Blocks editing on';
$string['blocksetup'] = 'Setting up block tables';
$string['blocksuccess'] = '{$a} tables have been set up correctly';
$string['brief'] = 'Brief';
$string['bulkactions'] = 'Bulk actions';
$string['bulkactionselect'] = '{$a} bulk action selection';
$string['bulkcancel'] = 'Close bulk edit';
$string['bulkmovecoursessuccess'] = 'Successfully moved {$a->courses} courses into {$a->category}';
$string['bulkselection'] = '{$a} selected';
$string['bycourseorder'] = 'By course order';
$string['byname'] = 'by {$a}';
$string['bypassed'] = 'Bypassed';
$string['cachecontrols'] = 'Cache controls';
$string['calltofeedback'] = 'The creators of this software would like your feedback.';
$string['calltofeedback_give'] = 'Give feedback about this software';
$string['calltofeedback_remind'] = 'Remind me later';
$string['cancel'] = 'Cancel';
$string['cancelled'] = 'Cancelled';
$string['categories'] = 'Course categories';
$string['categoriesandcourses'] = 'Course categories and courses';
$string['category'] = 'Category';
$string['categoryadded'] = 'The category \'{$a}\' was added';
$string['categorybulkaction'] = 'Bulk actions for selected categories';
$string['categorycontents'] = 'Subcategories and courses';
$string['categorycurrentcontents'] = 'Contents of {$a}';
$string['categorydeleted'] = 'The category \'{$a}\' was deleted';
$string['categoryduplicate'] = 'A category named \'{$a}\' already exists!';
$string['categoryheader'] = 'Category menu';
$string['categoryhidden'] = '(hidden)';
$string['categorymodifiedcancel'] = 'Category was modified! Please cancel and try again.';
$string['categoryname'] = 'Category name';
$string['categorypath'] = 'Category path';
$string['categorysubcategoryof'] = '{$a->category} - subcategory of {$a->parentcategory}';
$string['idnumbercoursecategory'] = 'Category ID number';
$string['idnumbercoursecategory_help'] = 'The ID number of a course category  is only used when matching the category against external systems and is not displayed anywhere on the site. If the category has an official code name it may be entered, otherwise the field can be left blank.';
$string['categoryupdated'] = 'The category \'{$a}\' was updated';
$string['changesmade'] = 'Changes made';
$string['changesmadereallygoaway'] = 'You have made changes. Are you sure you want to navigate away and lose your changes?';
$string['city'] = 'City/town';
$string['cleaningtempdata'] = 'Cleaning temp data';
$string['clear'] = 'Clear';
$string['clearall'] = 'Clear all';
$string['clearfilterrow'] = 'Remove filter row';
$string['clearfilters'] = 'Clear filters';
$string['clearsearch'] = 'Clear search input';
$string['clickhelpiconformoreinfo'] = '... continues ... Click on the help icon to read the full article';
$string['clickhere'] = 'Click here ...';
$string['clicktohideshow'] = 'Click to expand or collapse';
$string['closeblockdrawer'] = 'Close block drawer';
$string['closecourseindex'] = 'Close course index';
$string['closedrawer'] = 'Close drawer';
$string['closewindow'] = 'Close this window';
$string['closebuttontitle'] = 'Close';
$string['collapse'] = 'Collapse';
$string['collapseall'] = 'Collapse all';
$string['collapsecategory'] = 'Collapse {$a}';
$string['comebacklater'] = 'Please come back later.';
$string['commentincontext'] = 'Find this comment in context';
$string['comments'] = 'Comments';
$string['commentsnotenabled'] = 'Comments feature is not enabled';
$string['commentsrequirelogin'] = 'You need to log in to view the comments.';
$string['comparelanguage'] = 'Compare and edit current language';
$string['complete'] = 'Complete';
$string['completed'] = 'Completed';
$string['completereport'] = 'Complete report';
$string['configuration'] = 'Configuration';
$string['confirm'] = 'Confirm';
$string['confirmaccount'] = 'Confirm account';
$string['confirmdeletesection'] = 'Are you absolutely sure you want to completely delete "{$a}" and all the activities it contains?';
$string['confirmed'] = 'Your registration has been confirmed';
$string['confirmednot'] = 'Your registration has not yet been confirmed. Please check your mailbox for a confirmation email.';
$string['confirmcheckfull'] = 'Are you absolutely sure you want to confirm {$a} ?';
$string['confirmcoursemove'] = 'Are you sure you want to move this course ({$a->course}) into this category ({$a->category})?';
$string['considereddigitalminor'] = 'You are too young to create an account on this site.';
$string['contactsbyrolelist'] = '{$a->role}: {$a->contacts}';
$string['content'] = 'Content';
$string['contentexport_aboutthiscourse'] = 'Course summary';
$string['contentexport_coursesummary'] = 'This file is part of the content downloaded from <a href="{$a->courselink}">{$a->coursename}</a>.';
$string['contentexport_footersummary'] = 'This file is part of the content downloaded from <a href="{$a->courselink}">{$a->coursename}</a> by {$a->userfullname} on {$a->date}.';
$string['contentexport_modulesummary'] = 'This page is part of the content downloaded from <a href="{$a->modulelink}">{$a->modulename}</a> on {$a->date}. Note that some content and any files larger than {$a->maxfilesize} are not downloaded.';
$string['contentexport_viewfilename'] = 'View the file {$a}';
$string['contentbank'] = 'Content bank';
$string['context'] = 'Context';
$string['contextlevel'] = 'Context level';
$string['contextname'] = 'Context name';
$string['contextparent'] = 'Parent';
$string['contexturl'] = 'Context URL';
$string['continue'] = 'Continue';
$string['continuetocourse'] = 'Click here to enter your course';
$string['convertingwikitomarkdown'] = 'Converting wiki to Markdown';
$string['cookiesenabled'] = 'Cookies must be enabled in your browser';
$string['cookiesenabled_help'] = 'Two cookies are used on this site:

The essential one is the session cookie, usually called MoodleSession. You must allow this cookie in your browser to provide continuity and to remain logged in when browsing the site. When you log out or close the browser, this cookie is destroyed (in your browser and on the server).

The other cookie is purely for convenience, usually called MOODLEID or similar. It just remembers your username in the browser. This means that when you return to this site, the username field on the login page is already filled in for you. It is safe to refuse this cookie - you will just have to retype your username each time you log in.';
$string['cookiesenabled_help_html'] = 'Two cookies are used on this site:<br/><br/>

The essential one is the session cookie, usually called MoodleSession. You must allow this cookie in your browser to provide continuity and to remain logged in when browsing the site. When you log out or close the browser, this cookie is destroyed (in your browser and on the server).<br/><br/>

The other cookie is purely for convenience, usually called MOODLEID or similar. It just remembers your username in the browser. This means that when you return to this site, the username field on the login page is already filled in for you. It is safe to refuse this cookie - you will just have to retype your username each time you log in.';
$string['cookiesenabledonlysession'] = 'Cookies must be enabled in your browser';
$string['cookiesenabledonlysession_help'] = 'This site uses one session cookie, usually called MoodleSession. You must allow this cookie in your browser to provide continuity and to remain logged in when browsing the site. When you log out or close the browser, this cookie is destroyed (in your browser and on the server).';
$string['cookiesnotenabled'] = 'Unfortunately, cookies are currently not enabled in your browser';
$string['cookiesnotice'] = 'Cookies notice';
$string['copy'] = 'copy';
$string['copytoclipboard'] = 'Copy to clipboard';
$string['copyasnoun'] = 'copy';
$string['copycourse'] = 'Copy course';
$string['copyingcoursefiles'] = 'Copying course files';
$string['copyingsitefiles'] = 'Copying site files used in course';
$string['copyinguserfiles'] = 'Copying user files';
$string['copyingzipfile'] = 'Copying zip file';
$string['copyrightnotice'] = 'Copyright notice';
$string['coresystem'] = 'System';
$string['cost'] = 'Cost';
$string['costdefault'] = 'Default cost';
$string['count_of_total'] = '<strong>{$a->count}</strong> of {$a->total}';
$string['counteditems'] = '{$a->count} {$a->items}';
$string['country'] = 'Country';
$string['course'] = 'Course';
$string['courseheader'] = 'Course menu';
$string['courseadministration'] = 'Course administration';
$string['courseapprovedemail'] = 'Your requested course is approved, <a href="{$a->url}">{$a->name}</a>, and you are a {$a->teacher}.';
$string['courseapprovedemail2'] = 'Your requested course is approved: <a href="{$a->url}">{$a->name}</a>.';
$string['courseapprovedfailed'] = 'Failed to save the course as approved!';
$string['courseapprovedsubject'] = 'Your course has been approved.';
$string['courseavailable'] = 'This course is available to students';
$string['courseavailablenot'] = 'This course is not available to students';
$string['coursebackup'] = 'Course backup';
$string['coursebulkaction'] = 'Bulk actions for selected courses';
$string['coursecategories'] = 'Course categories';
$string['coursecategory'] = 'Course category';
$string['coursecategory_help'] = 'This setting determines the category in which the course will appear in the list of courses.';
$string['coursecategorydeleted'] = 'Deleted course category {$a}';
$string['coursecatmanagement'] = 'Course and category management';
$string['coursecompletion'] = 'Course completion';
$string['coursecompletions'] = 'Course completions';
$string['coursecreators'] = 'Course creator';
$string['coursecreatorsdescription'] = 'Course creators can create new courses.';
$string['coursedetails'] = 'Course details';
$string['coursedisplay'] = 'Course layout';
$string['coursedisplay_help'] = 'Course sections can be displayed all in one page or split over several pages.';
$string['coursedisplay_single'] = 'Show all sections on one page';
$string['coursedisplay_multi'] = 'Show one section per page';
$string['coursedeleted'] = 'Deleted course {$a}';
$string['courseextendednamedisplay'] = '{$a->shortname} {$a->fullname}';
$string['coursefiles'] = 'Legacy course files';
$string['coursefilesedit'] = 'Edit legacy course files';
$string['coursefileswarning'] = 'Course files are deprecated';
$string['coursefileswarning_help'] = 'Course files are deprecated since Moodle 2.0, please use external repositories instead as much as possible.';
$string['courseformatdata'] = 'Course format data';
$string['courseformats'] = 'Course formats';
$string['courseformatoptions'] = 'Formatting options for {$a}';
$string['courseformatudpate'] = 'Update format';
$string['courseprofiles'] = 'Course profiles';
$string['coursegrades'] = 'Course grades';
$string['coursehelpcategory'] = 'Position the course on the course listing and may make it easier for students to find it.';
$string['coursehelpforce'] = 'Force the course group mode to every activity in the course.';
$string['coursehelpformat'] = 'The course main page will be displayed in this format.';
$string['coursehelphiddensections'] = 'How the hidden sections in the course are displayed to students.';
$string['coursehelpmaximumupload'] = 'Define the largest size of file that can be uploaded in this course, limited by the site-wide setting.';
$string['coursehelpnewsitemsnumber'] = 'Number of recent announcements appearing in the latest announcements block on the course page. If set to zero, the announcements forum will not be created.';
$string['coursehelpnumberweeks'] = 'Number of sections in the course (applies to certain course formats only).';
$string['coursehelpshowgrades'] = 'Enable the display of the gradebook. It does not prevent grades from being displayed within the individual activities.';
$string['coursehidden'] = 'This course is currently unavailable to students';
$string['courseoverviewfiles'] = 'Course image';
$string['courseoverviewfilesext'] = 'Course image file extensions';
$string['courseoverviewfileslimit'] = 'Course image files limit';
$string['courseoverviewfiles_help'] = 'The course image is displayed in My courses and in the list of available courses on the Home page. Site administrators can enable additional file types and the use of multiple files. If you use multiple files, they will all be displayed in the list of available courses in the Home page.';
$string['courseinfo'] = 'Course information';
$string['coursenotaccessible'] = 'This course does not allow public access';
$string['courselegacyfiles'] = 'Legacy course files';
$string['courselegacyfiles_help'] = 'The course files area provides some backward compatibility with Moodle 1.9 and earlier.  All files in this area are always accessible to all participants in the course (whether you link to them or not) and there is no way to know where any of these files are being used in Moodle.

If you use this area to store course files, you can expose yourself to a number of privacy and security issues, as well as experiencing missing files in backups, course imports and any time content is shared or re-used.  It is therefore recommended that you do not use this area unless you really know what you are doing.';
$string['courselegacyfiles_link'] = 'coursefiles2';
$string['courselegacyfilesofcourse'] = 'Legacy course files: {$a}';
$string['courseoverview'] = 'Course overview';
$string['courseoverviewgraph'] = 'Course overview graph';
$string['coursereasonforrejecting'] = 'Your reasons for rejecting this request';
$string['coursereasonforrejectingemail'] = 'This will be emailed to the requester';
$string['coursereject'] = 'Reject a course request';
$string['courserejected'] = 'Course has been rejected and the requester has been notified.';
$string['courserejectemail'] = 'Sorry, but the course you requested has been rejected. Here is the reason provided:

{$a}';
$string['courserejectreason'] = 'Outline your reasons for rejecting this course<br />(this will be emailed to the requester)';
$string['courserejectsubject'] = 'Your course has been rejected';
$string['coursereport'] = 'Course report';
$string['coursereports'] = 'Course reports';
$string['courserequest'] = 'Course request';
$string['courserequestdetails'] = 'Details of the course you are requesting';
$string['courserequestfailed'] = 'For some reason, your course request could not be saved';
$string['courserequestintro'] = 'Use this form to request a course to be created for you.<br />Try and fill in as much information as you can to allow<br />the administrators to understand your reasons for wanting this course.';
$string['courserequestreason'] = 'Reasons for wanting this course';
$string['courserequestroleerror'] = 'The creators\' role in new courses configuration is invalid. Please see <a href="{$a}">user policies</a>.';
$string['courserequestsuccess'] = 'Course request submitted.';
$string['courserequestsupport'] = 'Supporting information to help the administrator evaluate this request';
$string['courserequestwarning'] = 'The user requesting this course will be automatically enrolled and assigned the role of {$a}.';
$string['courserestore'] = 'Course restore';
$string['coursereuse'] = 'Course reuse';
$string['coursereusenavigationmenu'] = 'Course reuse navigation menu';
$string['courses'] = 'Courses';
$string['coursesectionsummaries'] = 'Course section summaries';
$string['coursesectiontitle'] = '{$a->sectionname}: {$a->sectiontitle} | {$a->course}';
$string['coursesectiontitlebulkediting'] = 'Bulk edit {$a->sectionname}: {$a->sectiontitle} | {$a->course}';
$string['coursesectiontitleediting'] = 'Edit {$a->sectionname}: {$a->sectiontitle} | {$a->course}';
$string['coursesettings'] = 'Course default settings';
$string['coursesmovedout'] = 'Courses moved out from {$a}';
$string['coursespending'] = 'Courses pending approval';
$string['coursestart'] = 'Course start';
$string['coursesummary'] = 'Course summary';
$string['coursesummary_help'] = 'A short description of your course. The content you add here is searchable.';
$string['coursetitle'] = 'Course: {$a->course}';
$string['coursetitlebulkediting'] = 'Bulk edit course: {$a->course}';
$string['coursetitleediting'] = 'Edit course: {$a->course}';
$string['courseupdates'] = 'Course updates';
$string['coursevisibility'] = 'Course visibility';
$string['coursevisibility_help'] = '* Show: The course appears in the list of courses and students can access it.
* Hide: Access is restricted to teachers and other users with the capability to view hidden courses.';
$string['create'] = 'Create';
$string['createaccount'] = 'Create my new account';
$string['createcategory'] = 'Create category';
$string['createfolder'] = 'Create a folder in {$a}';
$string['createnew'] = 'Create new';
$string['createnewcategory'] = 'Create new category';
$string['createnewcourse'] = 'Create new course';
$string['createnewsubcategory'] = 'Create new subcategory';
$string['createsubcategoryof'] = 'Create subcategory of {$a}';
$string['createuser'] = 'Create user';
$string['createziparchive'] = 'Create zip archive';
$string['creatingblocks'] = 'Creating blocks';
$string['creatingblocksroles'] = 'Creating block level role assignments and overrides';
$string['creatingblogsinfo'] = 'Creating blogs info';
$string['creatingcategoriesandquestions'] = 'Creating categories and questions';
$string['creatingcoursemodules'] = 'Creating course modules';
$string['creatingcourseroles'] = 'Creating course level role assignments and overrides';
$string['creatingevents'] = 'Creating events';
$string['creatinggradebook'] = 'Creating gradebook';
$string['creatinggroupings'] = 'Creating groupings';
$string['creatinggroupingsgroups'] = 'Adding groups into groupings';
$string['creatinggroups'] = 'Creating groups';
$string['creatinglogentries'] = 'Creating log entries';
$string['creatingmessagesinfo'] = 'Creating messages info';
$string['creatingmodroles'] = 'Creating module level role assignments and overrides';
$string['creatingnewcourse'] = 'Creating new course';
$string['creatingrolesdefinitions'] = 'Creating roles definitions';
$string['creatingscales'] = 'Creating scales';
$string['creatingsections'] = 'Creating sections';
$string['creatingtemporarystructures'] = 'Creating temporary structures';
$string['creatinguserroles'] = 'Creating user level role assignments and overrides';
$string['creatingusers'] = 'Creating users';
$string['creatingxmlfile'] = 'Creating XML file';
$string['currency'] = 'Currency';
$string['currentcourse'] = 'Current course';
$string['currentcourseadding'] = 'Current course, adding data to it';
$string['currentcoursedeleting'] = 'Current course, deleting it first';
$string['currentlanguage'] = 'Current language';
$string['currentlocaltime'] = 'your current local time';
$string['currentpicture'] = 'Current picture';
$string['currentrelease'] = 'Current release information';
$string['currenttheme'] = 'Current theme';
$string['currentversion'] = 'Current version';
$string['databasechecking'] = 'Upgrading Moodle database from version {$a->oldversion} to {$a->newversion}';
$string['databaseperformance'] = 'Database performance';
$string['databasesetup'] = 'Setting up database';
$string['databasesuccess'] = 'Database was successfully upgraded';
$string['databaseupgradebackups'] = 'Backup version is now {$a}';
$string['databaseupgradeblocks'] = 'Blocks version is now {$a}';
$string['databaseupgradegroups'] = 'Groups version is now {$a}';
$string['databaseupgradelocal'] = 'Local database customisations version is now {$a}';
$string['databaseupgrades'] = 'Upgrading database';
$string['dataformats'] = 'Data formats';
$string['date'] = 'Date';
$string['datemostrecentfirst'] = 'Date - most recent first';
$string['datemostrecentlast'] = 'Date - most recent last';
$string['datetimefilterafter'] = '{$a->title} after';
$string['datetimefilterbefore'] = '{$a->title} before';
$string['day'] = 'day';
$string['days'] = 'days';
$string['decodinginternallinks'] = 'Decoding internal links';
$string['default'] = 'Default';
$string['defaulteditor'] = 'Default editor';
$string['defaultcategoryname'] = 'Category 1';
$string['defaultcompetencescale'] = 'Default competence scale';
$string['defaultcompetencescaledesc'] = 'A binary rating scale that provides no further information beyond whether someone has demonstrated proficiency or not.';
$string['defaultcompetencescalenotproficient'] = 'Not yet competent';
$string['defaultcompetencescaleproficient'] = 'Competent';
$string['defaultcoursestudent'] = 'Student';
$string['defaultcoursestudentdescription'] = 'Students generally have fewer privileges within a course.';
$string['defaultcoursestudents'] = 'Students';
$string['defaultcoursesummary'] = 'Write a concise and interesting paragraph here that explains what this course is about';
$string['defaultcourseteacher'] = 'Teacher';
$string['defaultcourseteacherdescription'] = 'Teachers can do anything within a course, including changing the activities and grading students.';
$string['defaultcourseteachers'] = 'Teachers';
$string['defaulthomepageuser'] = 'Start page';
$string['defaulthomepageuser_help'] = 'Which page should you be redirected to after logging in to the site?';
$string['delete'] = 'Delete';
$string['deleteablock'] = 'Delete a block';
$string['deleteall'] = 'Delete all';
$string['deleteallcannotundo'] = 'Delete all - cannot be undone';
$string['deleteallcomments'] = 'All comments';
$string['deleteallratings'] = 'All ratings';
$string['deletecategory'] = 'Delete category: {$a}';
$string['deletecategoryempty'] = 'This category is empty.';
$string['deletecategorycheck'] = 'Are you absolutely sure you want to completely delete this category <b>\'{$a}\'</b>?<br />This will move all courses into the parent category if there is one, or into Miscellaneous.';
$string['deletecategorycheck2'] = 'If you delete this category, you need to choose what to do with the courses and subcategories it contains.';
$string['deletecommentbyon'] = 'Delete comment posted by {$a->user} on {$a->time}';
$string['deletecompletely'] = 'Delete completely';
$string['deletecourse'] = 'Delete a course';
$string['deletecoursecheck'] = 'Are you absolutely sure you want to completely delete this course and all the data it contains?';
$string['deleted'] = 'Deleted';
$string['deletedactivity'] = 'Deleted {$a}';
$string['deletedcourse'] = '{$a} has been completely deleted';
$string['deletednot'] = 'Could not delete {$a}.';
$string['deletecheck'] = 'Delete {$a} ?';
$string['deletechecktype'] = 'Are you sure that you want to delete this {$a->type}?';
$string['deletechecktypename'] = 'Are you sure that you want to delete the {$a->type} "{$a->name}"?';
$string['deletecheckfiles'] = 'Are you absolutely sure you want to delete these files?';
$string['deletecheckfull'] = 'Are you sure you want to delete user {$a}, including data such as profile details, enrolments, group and cohort membership and some user activity data?';
$string['deletecheckwarning'] = 'You are about to delete these files';
$string['deletepicture'] = 'Delete picture';
$string['deletesection'] = 'Delete';
$string['deleteselected'] = 'Delete selected';
$string['deleteselectedkey'] = 'Delete selected key';
$string['deletingcourse'] = 'Deleting {$a}';
$string['deletingexistingcoursedata'] = 'Deleting existing course data';
$string['deletingolddata'] = 'Deleting old data';
$string['department'] = 'Department';
$string['desc'] = 'Descending';
$string['description'] = 'Description';
$string['deselectall'] = 'Deselect all';
$string['deselectnos'] = 'Deselect all \'No\'';
$string['details'] = 'Details';
$string['detailedless'] = 'Less detailed';
$string['detailedmore'] = 'More detailed';
$string['digitalminor'] = 'Digital minor';
$string['digitalminor_desc'] = 'Please ask your parent/guardian to contact:';
$string['directory'] = 'Directory';
$string['disable'] = 'Disable';
$string['disabledcomments'] = 'Comments are disabled';
$string['dismissnotification'] = 'Dismiss this notification';
$string['displayingfirst'] = 'Only the first {$a->count} {$a->things} are displayed';
$string['displayingrecords'] = 'Displaying {$a} records';
$string['displayingusers'] = 'Displaying users {$a->start} to {$a->end}';
$string['displayonpage'] = 'Display on page';
$string['dndcourse'] = 'You can drag and drop this course to alter its sorting or to move it to another category.';
$string['dndenabled_inbox'] = 'You can drag and drop files here to add them.';
$string['dndnotsupported'] = 'Drag and drop upload not supported';
$string['dndnotsupported_help'] = 'Your browser does not support drag and drop upload. This feature is available in all recent versions of Chrome, Firefox and Safari, as well as Internet Explorer v10 and above.';
$string['dndnotsupported_insentence'] = 'drag and drop not supported';
$string['dnduploadwithoutcontent'] = 'This upload does not have any content';
$string['dndworkingfiletextlink'] = 'Drag and drop files, text or links onto course sections to upload them';
$string['dndworkingfilelink'] = 'Drag and drop files or links onto course sections to upload them';
$string['dndworkingfiletext'] = 'Drag and drop files or text onto course sections to upload them';
$string['dndworkingfile'] = 'Drag and drop files onto course sections to upload them';
$string['dndworkingtextlink'] = 'Drag and drop text or links onto course sections to upload them';
$string['dndworkingtext'] = 'Drag and drop text onto course sections to upload it';
$string['dndworkinglink'] = 'Drag and drop links onto course sections to upload them';
$string['documentation'] = 'Moodle documentation';
$string['dontsortcategories'] = 'Don\'t sort categories';
$string['dontsortcourses'] = 'Don\'t sort courses';
$string['down'] = 'Down';
$string['download'] = 'Download';
$string['downloadall'] = 'Download all';
$string['downloadexcel'] = 'Download in Excel format';
$string['downloadfile'] = 'Download file';
$string['downloadods'] = 'Download in ODS format';
$string['downloadtext'] = 'Download in text format';
$string['doyouagree'] = 'Have you read these conditions and understood them?';
$string['droptoupload'] = 'Drop files here to upload';
$string['duplicate'] = 'Duplicate';
$string['duplicatedmodule'] = '{$a} (copy)';
$string['duplicatedsection'] = '{$a} (copy)';
$string['edhelpaspellpath'] = 'To use spell-checking within the editor, you MUST have <strong>aspell 0.50</strong> or later installed on your server, and you must specify the correct path to access the aspell binary.  On Unix/Linux systems, this path is usually <strong>/usr/bin/aspell</strong>, but it might be something else.';
$string['edhelpbgcolor'] = 'Define the edit area\'s background color.<br />Valid values are, for example: #FFFFFF or white';
$string['edhelpcleanword'] = 'This setting enables or disables Word-specific format filtering.';
$string['edhelpenablespelling'] = 'Enable or disable spell-checking. When enabled, <strong>aspell</strong> must be installed on the server. The second value is the <strong>default dictionary</strong>. This value will be used if aspell doesn\'t have dictionary for users own language.';
$string['edhelpfontfamily'] = 'The font-family property is a list of font family names and/or generic family names. Family names must be separated with comma.';
$string['edhelpfontlist'] = 'Define the fonts used on editors dropdown menu.';
$string['edhelpfontsize'] = 'The default font-size sets the size of a font. <br />Valid values are for example: medium, large, smaller, larger, 10pt, 11px.';
$string['edit'] = 'Edit';
$string['edita'] = 'Edit {$a}';
$string['editcategorysettings'] = 'Edit category settings';
$string['editcategorythis'] = 'Edit this category';
$string['editcoursesettings'] = 'Edit course settings';
$string['editsettings'] = 'Edit settings';
$string['editfiles'] = 'Edit files';
$string['editgroupprofile'] = 'Edit group description';
$string['editingteachershort'] = 'Editor';
$string['editmode'] = 'Edit mode';
$string['editlock'] = 'This value cannot be edited!';
$string['editmyprofile'] = 'Edit profile';
$string['editorbgcolor'] = 'Background-color';
$string['editorcleanonpaste'] = 'Clean Word HTML on paste';
$string['editorcommonsettings'] = 'Common settings';
$string['editordefaultfont'] = 'Default font';
$string['editorenablespelling'] = 'Enable spellchecking';
$string['editorfontlist'] = 'Fontlist';
$string['editorfontsize'] = 'Default font-size';
$string['editorpreferences'] = 'Editor preferences';
$string['editorresettodefaults'] = 'Reset to default values';
$string['editorsettings'] = 'Editor settings';
$string['editorshortcutkeys'] = 'Editor shortcut keys';
$string['editsection'] = 'Edit settings';
$string['editsectionname'] = 'Edit section name';
$string['editsectionsettings'] = 'Edit section settings';
$string['editsectiontitle'] = 'Edit section: {$a}';
$string['edittitle'] = 'Edit title';
$string['edittitleinstructions'] = 'Escape to cancel, Enter when finished';
$string['editthisactivity'] = 'Edit this activity';
$string['editthiscategory'] = 'Edit this category';
$string['edituser'] = 'Edit user accounts';
$string['edulevelother'] = 'Other';
$string['edulevelteacher'] = 'Teaching';
$string['edulevelparticipating'] = 'Participating';
$string['edulevel'] = 'All events';
$string['edulevel_help'] = '* Teaching - actions performed by a teacher, e.g. updating a resource
* Participating - actions performed by a student, e.g. posting in a forum
* Other - actions performed by a user with a role other than teacher or student';
$string['email'] = 'Email address';
$string['emailalreadysent'] = 'A password reset email has already been sent. Please check your email.';
$string['emailactive'] = 'Email activated';
$string['emailagain'] = 'Email (again)';
$string['emailconfirm'] = 'Confirm your account';
$string['emailconfirmation'] = 'Hi {$a->firstname},

A new account has been requested at \'{$a->sitename}\'
using your email address.

To confirm your new account, please go to this web address:

{$a->link}

In most mail programs, this should appear as a blue link
which you can just click on.  If that doesn\'t work,
then cut and paste the address into the address
line at the top of your web browser window.

If you need help, please contact the site administrator,
{$a->admin}';
$string['emailconfirmationresend'] = 'Resend confirmation email';
$string['emailconfirmationsubject'] = '{$a}: account confirmation';
$string['emailconfirmsent'] = '<p>An email should have been sent to your address at <b>{$a}</b></p>
   <p>It contains easy instructions to complete your registration.</p>
   <p>If you continue to have difficulty, contact the site administrator.</p>';
$string['emailconfirmsentfailure'] = 'Confirmation email failed to send';
$string['emailconfirmsentsuccess'] = 'Confirmation email sent successfully';
$string['emaildigest'] = 'Email digest type';
$string['emaildigest_help'] = 'This is the daily digest setting that forums will use by default.

* No digest - you will receive one e-mail per forum post;
* Digest - complete posts - you will receive one digest e-mail per day containing the complete contents of each forum post;
* Digest - subjects only - you will receive one digest e-mail per day containing just the subject of each forum post.

You can also choose a different setting for each forum if you wish.';
$string['emaildigestcomplete'] = 'Complete (daily email with full posts)';
$string['emaildigestoff'] = 'No digest (single email per forum post)';
$string['emaildigestsubjects'] = 'Subjects (daily email with subjects only)';
$string['emaildisable'] = 'This email address is disabled';
$string['emaildisableclick'] = 'Click here to disable all email from being sent to this address';
$string['emaildisplay'] = 'Email visibility';
$string['emaildisplay_help'] = '* Hidden - Only users with appropriate permissions such as teachers can view your email address.
* Visible to everyone - All users on the site can view your email address.
* Visible to course participants - Only participants of courses you are enrolled in can view your email address.';
$string['emaildisplaycourse'] = 'Visible to course participants';
$string['emaildisplaycoursemembersonly'] = '(Visible to other course participants)';
$string['emaildisplayeveryone'] = '(Visible to everyone)';
$string['emaildisplayhide'] = '(Hidden from everyone except users with appropriate permissions)';
$string['emaildisplayno'] = 'Hidden';
$string['emaildisplayyes'] = 'Visible to everyone';
$string['emailenable'] = 'This email address is enabled';
$string['emailenableclick'] = 'Click here to re-enable all email being sent to this address';
$string['emailexists'] = 'This email address is already registered.';
$string['emailexistssignuphint'] = 'Perhaps you created an account in the past? {$a}';
$string['emailexistshintlink'] = 'Recover forgotten username or password';
$string['emailformat'] = 'Email format';
$string['emailcharset'] = 'Email charset';
$string['emailmustbereal'] = 'Note: your email address must be a real one';
$string['emailnotallowed'] = 'Email addresses in these domains are not allowed ({$a})';
$string['emailnotfound'] = 'The email address was not found in the database';
$string['emailonlyallowed'] = 'This email cannot be used. Allowed email domains are: {$a}.';
$string['emailpasswordconfirmation'] = 'Hi {$a->firstname},

Someone (probably you) has requested a new password for your
account on \'{$a->sitename}\'.

To confirm this and have a new password sent to you via email,
go to the following web address:

{$a->link}

In most mail programs, this should appear as a blue link
which you can just click on.  If that doesn\'t work,
then cut and paste the address into the address
line at the top of your web browser window.

If you need help, please contact the site administrator,
{$a->admin}';
$string['emailpasswordconfirmationsubject'] = '{$a}: Change password confirmation';
$string['emailpasswordconfirmmaybesent'] = '<p>If you supplied a correct username or unique email address then an email should have been sent to you.</p>
   <p>It contains easy instructions to confirm and complete this password change.
If you continue to have difficulty, please contact the site administrator.</p>';
$string['emailpasswordconfirmnoemail'] = '<p>The user account you specified does not have a recorded email address.</p>
   <p>Please contact the site administrator.</p>';
$string['emailpasswordconfirmnotsent'] = '<p>The user detail you supplied does not identify an existing user account.</p>
   <p>Please check the information you entered, then try again.
If you continue to have difficulty, please contact the site administrator.</p>';
$string['emailpasswordconfirmsent'] = 'An email should have been sent to your address at <b>{$a}</b>.
<br />It contains easy instructions to confirm and complete this password change.
If you continue to have difficulty, contact the site administrator.';
$string['emailpasswordchangeinfo'] = 'Hi {$a->firstname},

Someone (probably you) has requested a new password for your
account \'{$a->username}\' on \'{$a->sitename}\'.

To change your password, please go to the following web address:

{$a->link}

In most mail programs, this should appear as a blue link
which you can just click on.  If that doesn\'t work,
then cut and paste the address into the address
line at the top of your web browser window.

If you need help, please contact the site administrator,
{$a->admin}';
$string['emailpasswordchangeinfodisabled'] = 'Hi {$a->firstname},

Someone (probably you) has requested a new password for your account on \'{$a->sitename}\'.

Unfortunately your account on this site is disabled, so the password cannot be reset. Please contact the site administrator {$a->admin}.';
$string['emailpasswordchangeinfofail'] = 'Hi {$a->firstname},

Someone (probably you) has requested a new password for your account on \'{$a->sitename}\'.

Unfortunately passwords cannot be reset on this site. Please contact the site administrator {$a->admin}.';
$string['emailpasswordchangeinfosubject'] = '{$a}: Change password information';
$string['emailresetconfirmation'] = 'Hi {$a->firstname},

A password reset was requested for your account \'{$a->username}\' at {$a->sitename}.

To confirm this request, and set a new password for your account, please go to the following web address:
<a href="{$a->link}">{$a->link}</a>

(This link is valid for {$a->resetminutes} minutes from the time this reset was first requested.)

If this password reset was not requested by you, no action is needed.

If you need help, please contact the site administrator, {$a->admin}';
$string['emailresetconfirmationsubject'] = '{$a}: Password reset request';
$string['emailresetconfirmsent'] = 'An email has been sent to your address at <b>{$a}</b>.
<br />It contains easy instructions to confirm and complete this password change.
If you continue to have difficulty, contact the site administrator.';
$string['emailstop'] = 'Disable notifications';
$string['emailtoprivatefiles'] = 'You can also e-mail files as attachments straight to your private files space. Simply attach your files to an e-mail and send it to {$a}';
$string['emailtoprivatefilesdenied'] = 'Your administrator has disabled the option to upload your own private files.';
$string['emailvia'] = '{$a->name} (via {$a->siteshortname})';
$string['emojicategoryactivities'] = 'Activities';
$string['emojicategoryanimalsnature'] = 'Animals & nature';
$string['emojicategoryflags'] = 'Flags';
$string['emojicategoryfooddrink'] = 'Food & drink';
$string['emojicategoryobjects'] = 'Objects';
$string['emojicategorypeoplebody'] = 'People & body';
$string['emojicategoryrecent'] = 'Recent';
$string['emojicategorysmileysemotion'] = 'Smileys & emotion';
$string['emojicategorysymbols'] = 'Symbols';
$string['emojicategorytravelplaces'] = 'Travel & places';
$string['emptycmids'] = 'Empty course module IDs';
$string['emptydragdropregion'] = 'empty region';
$string['emptysectionids'] = 'Empty section IDs';
$string['enable'] = 'Enable';
$string['encryptedcode'] = 'Encrypted code';
$string['enddate'] = 'Course end date';
$string['enddate_help'] = 'The end date doesn’t restrict student access to the course. It determines whether a course is listed as Past in My courses.';
$string['enddatewithtaskenabled'] = 'Course end date';
$string['enddatewithtaskenabled_help'] = 'The date when the course becomes hidden for students and they can no longer access it.';
$string['english'] = 'English';
$string['enrolmentmethods'] = 'Enrolment methods';
$string['entercourse'] = 'Click to enter this course';
$string['enteremail'] = 'Enter your email address';
$string['enteremailaddress'] = 'Enter in your email address to reset your
   password and have the new password sent to you via email.';
$string['enterusername'] = 'Enter your username';
$string['entries'] = 'Entries';
$string['error'] = 'Error';
$string['errorcreatingactivity'] = 'Unable to create an instance of activity \'{$a}\'';
$string['errorfiletoobig'] = 'The file was bigger than the limit of {$a} bytes';
$string['errornouploadrepo'] = 'There is no upload repository enabled for this site';
$string['errorwhenconfirming'] = 'You are not confirmed yet because an error occurred.  If you clicked on a link in an email to get here, make sure that the line in your email wasn\'t broken or wrapped. You may have to use cut and paste to reconstruct the link properly.';
$string['eventcommentcreated'] = 'Comment created';
$string['eventcommentdeleted'] = 'Comment deleted';
$string['eventcommentsviewed'] = 'Comments viewed';
$string['eventconfiglogcreated'] = 'Config log created';
$string['eventcoursebackupcreated'] = 'Course backup created';
$string['eventcoursecategorycreated'] = 'Category created';
$string['eventcoursecategorydeleted'] = 'Category deleted';
$string['eventcoursecategoryupdated'] = 'Category updated';
$string['eventcoursecategoryviewed'] = 'Category viewed';
$string['eventcoursecontentdeleted'] = 'Course content deleted';
$string['eventcoursecreated'] = 'Course created';
$string['eventcoursedeleted'] = 'Course deleted';
$string['eventcourseended'] = 'Course ended';
$string['eventcourseinformationviewed'] = 'Course summary viewed';
$string['eventcoursemodulecreated'] = 'Course module created';
$string['eventcoursemoduledeleted'] = 'Course module deleted';
$string['eventcoursemoduleupdated'] = 'Course module updated';
$string['eventcoursemoduleviewed'] = 'Course module viewed';
$string['eventcourseoverviewviewed'] = 'Course activities overview page viewed';
$string['eventcoursessearched'] = 'Courses searched';
$string['eventcourseresetended'] = 'Course reset ended';
$string['eventcourseresetstarted'] = 'Course reset started';
$string['eventcourserestored'] = 'Course restored';
$string['eventcoursestarted'] = 'Course started';
$string['eventcourseupdated'] = 'Course updated';
$string['eventcoursesectioncreated'] = 'Course section created';
$string['eventcoursesectiondeleted'] = 'Course section deleted';
$string['eventcoursesectionupdated'] = 'Course section updated';
$string['eventcoursemoduleinstancelistviewed'] = 'Course module instance list viewed';
$string['eventcourseuserreportviewed'] = 'Course user report viewed';
$string['eventcourseviewed'] = 'Course viewed';
$string['eventdashboardreset'] = 'Dashboard reset';
$string['eventdashboardsreset'] = 'Dashboards reset';
$string['eventdashboardviewed'] = 'Dashboard viewed';
$string['eventdatabasetextfieldcontentreplaced'] = 'Database global search and replace';
$string['eventemailfailed'] = 'Email failed to send';
$string['eventmycoursesviewed'] = 'My courses viewed';
$string['eventname'] = 'Event name';
$string['eventrecentactivityviewed'] = 'Recent activity viewed';
$string['eventsearchindexed'] = 'Search data indexed';
$string['eventsearchresultsviewed'] = 'Search results viewed';
$string['eventsectionviewed'] = 'Section viewed';
$string['eventunknownlogged'] = 'Unknown event';
$string['eventurlblocked'] = 'The URL was blocked';
$string['eventusercreated'] = 'User created';
$string['eventuserdeleted'] = 'User deleted';
$string['eventuserfeedbackgiven'] = 'Feedback link clicked';
$string['eventuserfeedbackremind'] = 'Remind me later feedback link clicked';
$string['eventuserlistviewed'] = 'User list viewed';
$string['eventuserloggedout'] = 'User logged out';
$string['eventuserpasswordpolicyfailed'] = 'User password failed password policy';
$string['eventuserpasswordupdated'] = 'User password updated';
$string['eventuserprofileviewed'] = 'User profile viewed';
$string['eventuserupdated'] = 'User updated';
$string['eventuserinfofieldcreated'] = 'User profile field created';
$string['eventuserinfofieldupdated'] = 'User profile field updated';
$string['eventuserinfofielddeleted'] = 'User profile field deleted';
$string['eventuserinfocategorycreated'] = 'User profile field category created';
$string['eventuserinfocategoryupdated'] = 'User profile field category updated';
$string['eventuserinfocategorydeleted'] = 'User profile field category deleted';
$string['everybody'] = 'Everybody';
$string['executeat'] = 'Execute at';
$string['existing'] = 'Existing';
$string['existingadmins'] = 'Existing admins';
$string['existingcourse'] = 'Existing course';
$string['existingcourseadding'] = 'Existing course, adding data to it';
$string['existingcoursedeleting'] = 'Existing course, deleting it first';
$string['existingcreators'] = 'Existing course creators';
$string['existingstudents'] = 'Enrolled students';
$string['existingteachers'] = 'Existing teachers';
$string['extendsession'] = 'Extend session';
$string['expand'] = 'Expand';
$string['expandall'] = 'Expand all';
$string['expandcategory'] = 'Expand {$a}';
$string['explanation'] = 'Explanation';
$string['explanationdigitalminor'] = 'This information is required to determine if your age is over the digital age of consent. This is the age when an individual can consent to terms and conditions and their data being legally stored and processed.';
$string['extendperiod'] = 'Extended period';
$string['favourites'] = 'Starred';
$string['failedloginattempts'] = '{$a->attempts} failed logins since your last login';
$string['failedtaskbody'] = '<p>Hi {$a->firstname},</p>
<p>The task <b>{$a->taskname}</b> has failed multiple times and requires attention.</p>
<p><a href="{$a->link}">See task</a></p>';
$string['failedtasksubject'] = 'Task failed: {$a}';
$string['feedback'] = 'Feedback';
$string['file'] = 'File';
$string['fileexists'] = 'There is already a file called {$a}';
$string['filemissing'] = '{$a} is missing';
$string['filereaderror'] = 'Unable to read the file \'{$a}\'. Please check that it really is a file and not a folder.';
$string['files'] = 'Files';
$string['filesanduploads'] = 'Files and uploads';
$string['filesfolders'] = 'Files/folders';
$string['fileuploadwithcontent'] = 'File uploads should not include the content parameter';
$string['filloutallfields'] = 'Please fill out all fields in this form';
$string['filter'] = 'Filter';
$string['filtersetmatchdescription'] = 'How multiple filters should be combined';
$string['findmorecourses'] = 'Find more courses...';
$string['first'] = 'First';
$string['firstaccess'] = 'First access';
$string['firstname'] = 'First name';
$string['firstnamephonetic'] = 'First name - phonetic';
$string['firstpage'] = 'First page';
$string['firstsiteaccess'] = 'First access to site';
$string['firsttime'] = 'Is this your first time here?';
$string['folder'] = 'Folder';
$string['folderclosed'] = 'Closed folder';
$string['folderopened'] = 'Opened folder';
$string['followingoptional'] = 'The following items are optional';
$string['followingrequired'] = 'The following items are required';
$string['for'] = 'For';
$string['force'] = 'Force';
$string['forcelanguage'] = 'Force language';
$string['forceno'] = 'Do not force';
$string['forcepasswordchange'] = 'Force password change';
$string['forcepasswordchange_help'] = 'If ticked, the user will be prompted to change their password when they next log in.';
$string['forcepasswordchangecheckfull'] = 'Are you absolutely sure you want to force a password change to {$a} ?';
$string['forcepasswordchangenot'] = 'Could not force a password change to {$a}';
$string['forcepasswordchangenotice'] = 'You must change your password to proceed.';
$string['forcepasswordresetfailurenotice'] = 'Your current password no longer passes the set password policy. Please contact your Moodle administrator for assistance.
   {$a}';
$string['forcepasswordresetnotice'] = 'Your current password no longer passes the password policy. You must reset your password to log in.
   {$a}';
$string['forcetheme'] = 'Force theme';
$string['forgotaccount'] = 'Lost password?';
$string['forgotten'] = 'Forgotten your username or password?';
$string['forgottenduplicate'] = 'The email address is shared by several accounts, please enter username instead';
$string['forgotteninvalidurl'] = 'Invalid password reset URL';
$string['format'] = 'Format';
$string['formathtml'] = 'HTML format';
$string['formatmarkdown'] = 'Markdown format';
$string['formatplain'] = 'Plain text format';
$string['formattext'] = 'Moodle auto-format';
$string['forumpreferences'] = 'Forum preferences';
$string['framesetinfo'] = 'This frameset document contains:';
$string['fromdate'] = 'From';
$string['fromsender'] = 'From';
$string['frontpagecategorycombo'] = 'Combo list';
$string['frontpagecategorynames'] = 'List of categories';
$string['frontpagecourselist'] = 'List of courses';
$string['frontpagecoursesearch'] = 'Course search box';
$string['frontpageenrolledcourselist'] = 'Enrolled courses';
$string['frontpagedescription'] = 'Site home summary';
$string['frontpagedescriptionhelp'] = 'This summary can be displayed on the site home using the course/site summary block.';
$string['frontpageformat'] = 'Site home format';
$string['frontpageformatloggedin'] = 'Site home format when logged in';
$string['frontpagenews'] = 'Announcements';
$string['frontpagesettings'] = 'Site home settings';
$string['fulllistofcourses'] = 'All courses';
$string['fullname'] = 'Full name'; /* @deprecated - Use fullnamecourse or fullnameuser or some own context specific string. */
$string['fullnamecourse'] = 'Course full name';
$string['fullnamecourse_help'] = 'The name displayed in My courses and in the list of available courses on the Home page.';
$string['fullnamedisplay'] = '{$a->firstname} {$a->lastname}';
$string['fullnameuser'] = 'User full name';
$string['fullprofile'] = 'Full profile';
$string['fullsitename'] = 'Full site name';
$string['functiondisabled'] = 'That functionality is currently disabled';
$string['general'] = 'General';
$string['geolocation'] = 'latitude - longitude';
$string['gettheselogs'] = 'Get these logs';
$string['go'] = 'Go';
$string['gobacktosite'] = 'Go back to site';
$string['gpl'] = 'Copyright (C) 1999 onwards Martin Dougiamas (https://moodle.com)

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the Moodle License information page for full details: https://moodledev.io/general/license';
$string['gpllicense'] = 'GPL license';
$string['gpl3'] = 'Copyright (C) 1999 onwards Martin Dougiamas (https://moodle.com)

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the Moodle License information page for full details: https://moodledev.io/general/license';
$string['gradable'] = 'Gradable';
$string['grades'] = 'Grades';
$string['gradenoun'] = 'Grade';
$string['gradeverb'] = 'Grade';
$string['gravatarenabled'] = '<a href="https://www.gravatar.com/">Gravatar</a> has been enabled for this site. If you don\'t upload a profile picture Moodle will attempt to load a profile picture for you from Gravatar.';
$string['group'] = 'Group';
$string['groupadd'] = 'Add new group';
$string['groupaddusers'] = 'Add selected to group';
$string['groupfor'] = 'for group';
$string['groupinfo'] = 'Info about selected group';
$string['groupinfoedit'] = 'Edit group settings';
$string['groupinfomembers'] = 'Info about selected members';
$string['groupinfopeople'] = 'Info about selected people';
$string['groupmembers'] = 'Group members';
$string['groupmemberssee'] = 'See group members';
$string['groupmembersselected'] = 'Members of selected group';
$string['groupmode'] = 'Group mode';
$string['groupmodeforce'] = 'Force group mode';
$string['groupmy'] = 'My group';
$string['groupnonmembers'] = 'People not in a group';
$string['groupnotamember'] = 'Sorry, you are not a member of that group';
$string['grouprandomassign'] = 'Randomly assign all to groups';
$string['groupremove'] = 'Remove selected group';
$string['groupremovemembers'] = 'Remove selected members';
$string['groups'] = 'Groups';
$string['groupsnone'] = 'No groups';
$string['groupsseparate'] = 'Separate groups';
$string['groupsvisible'] = 'Visible groups';
$string['guest'] = 'Guest';
$string['guestdescription'] = 'Guests have minimal privileges and usually can not enter text anywhere.';
$string['guestskey'] = 'Allow guests who have the key';
$string['guestsno'] = 'Do not allow guests in';
$string['guestsnotallowed'] = 'Sorry, \'{$a}\' does not allow guests to enter.';
$string['guestsyes'] = 'Allow guests without the key';
$string['guestuser'] = 'Guest user';
$string['guestuserinfo'] = 'This user is a special user that allows read-only access to some courses.';
$string['help'] = 'Help';
$string['helpprefix2'] = 'Help with {$a}';
$string['helpwiththis'] = 'Help with this';
$string['hiddenassign'] = 'Hidden assignment';
$string['hiddenfromstudents'] = 'Hidden from students';
$string['hiddenoncoursepage'] = 'Available but not shown on course page';
$string['hiddensections'] = 'Hidden sections';
$string['hiddensectionscollapsed'] = 'Show section names only';
$string['hiddensectionscollapsed_description'] = 'Section names are displayed to students, but section contents are hidden.';
$string['hiddensectionsinvisible'] = 'Hide completely';
$string['hiddensectionsinvisible_description'] = 'Hidden sections are not displayed to students.';
$string['hiddenwithbrackets'] = '(hidden)';
$string['hide'] = 'Hide';
$string['hideadvancedsettings'] = 'Hide advanced settings';
$string['hidecategory'] = 'Hide category?';
$string['hidecategorymany'] = 'The category {$a->category} contains {$a->coursecount} courses.
<br/>If you hide it, users without permission to view hidden categories will no longer have access to the courses.';
$string['hidecategoryone'] = 'The category {$a->category} contains 1 course.
<br/>If you hide it, users without permission to view hidden categories will no longer have access to the course.';
$string['hidechartdata'] = 'Hide chart data';
$string['hidefromstudents'] = 'Hide on course page';
$string['hideoncoursepage'] = 'Make available but don\'t show on course page';
$string['hidesection'] = 'Hide section {$a}';
$string['hidesettings'] = 'Hide settings';
$string['hideshowblocks'] = 'Hide or show blocks';
$string['hidepopoverwindow'] = 'Hide popover window';
$string['highlight'] = 'Highlight';
$string['highlighted'] = 'Highlighted';
$string['highlightoff'] = 'Unhighlight';
$string['hits'] = 'Hits';
$string['hitsoncourse'] = 'Hits on {$a->coursename} by {$a->username}';
$string['hitsoncoursetoday'] = 'Today\'s hits on {$a->coursename} by {$a->username}';
$string['home'] = 'Home';
$string['homeheader'] = 'Home menu';
$string['hour'] = 'hour';
$string['hours'] = 'hours';
$string['howtomakethemes'] = 'How to make new themes';
$string['htmleditor'] = 'Use HTML editor';
$string['htmleditoravailable'] = 'The HTML editor is available';
$string['htmleditordisabled'] = 'You have disabled the HTML editor in your user profile';
$string['htmleditordisabledadmin'] = 'The administrator has disabled the HTML editor on this site';
$string['htmleditordisabledbrowser'] = 'The HTML editor is unavailable because your web browser is not compatible';
$string['htmlfilesonly'] = 'HTML files only';
$string['htmlformat'] = 'Pretty HTML format';
$string['changedpassword'] = 'Changed password';
$string['changepassword'] = 'Change password';
$string['changessaved'] = 'Changes saved';
$string['check'] = 'Check';
$string['checkactual'] = 'Actual';
$string['checkerror'] = 'Error getting result of check \'{$a}\'. Check the browser console for more information.';
$string['checkexpected'] = 'Expected';
$string['checks'] = 'Checks';
$string['checksok'] = 'All \'{$a}\' checks OK';
$string['checkall'] = 'Check all';
$string['checkingbackup'] = 'Checking backup';
$string['checkingcourse'] = 'Checking course';
$string['checkingforbbexport'] = 'Checking for BlackBoard export';
$string['checkinginstances'] = 'Checking instances';
$string['checkingsections'] = 'Checking sections';
$string['checklanguage'] = 'Check language';
$string['checkloading'] = 'Getting the result of check \'{$a}\'';
$string['checknone'] = 'Check none';
$string['childcoursenotfound'] = 'Child course not found!';
$string['childcourses'] = 'Child courses';
$string['choose'] = 'Choose';
$string['choosecourse'] = 'Choose a course';
$string['choosedots'] = 'Choose...';
$string['chooselivelogs'] = 'Or watch current activity';
$string['chooselogs'] = 'Choose which logs you want to see';
$string['choosereportfilter'] = 'Choose a filter for the report';
$string['choosetheme'] = 'Choose theme';
$string['chooseuser'] = 'Choose a user';
$string['courseduration'] = 'Course duration';
$string['courseduration_desc'] = 'The course duration is used to calculate the default course end date. The course end date is used for determining whether a course should be included in a user\'s list of courses.  It may also be used by custom reports. Users can still enter the course after the end date.';
$string['courseenddateenabled'] = 'Course end date enabled by default';
$string['courseenddateenabled_desc'] = 'This setting determines if the course end date will be enabled by default for new courses and set to the date calculated from the course duration.';
$string['eventcontentviewed'] = 'Content viewed';
$string['filteroption'] = '{$a->criteria}: {$a->value}';
$string['filterrowlegend'] = 'Filter {$a}';
$string['filters'] = 'Filters';
$string['filtertype'] = 'Filter type';
$string['icon'] = 'Icon';
$string['idnumber'] = 'ID number';
$string['idnumbercourse'] = 'Course ID number';
$string['idnumbercourse_help'] = 'Only used to connect the course with external systems. Leave blank if you don\'t have an official course ID.';
$string['idnumbergroup'] = 'Group ID number';
$string['idnumbergroup_help'] = 'The ID number of a group is only used when matching the group against external systems and is not displayed anywhere on the site. If the group has an official code name it may be entered, otherwise the field can be left blank.';
$string['idnumbergrouping'] = 'Grouping ID number';
$string['idnumbergrouping_help'] = 'The ID number of a grouping is only used when matching the grouping against external systems and is not displayed anywhere on the site. If the grouping has an official code name it may be entered, otherwise the field can be left blank.';
$string['idnumbermod'] = 'ID number';
$string['idnumbermod_help'] = 'Setting an ID number provides a way of identifying the activity or resource for purposes such as grade calculation or custom reporting. Otherwise the field may be left blank.

For gradable activities, the ID number can also be set in the gradebook, though it can only be edited on the activity settings page.';
$string['idnumbertaken'] = 'This ID number is already taken';
$string['imagealt'] = 'Picture description';
$string['import'] = 'Import';
$string['importdata'] = 'Import course data';
$string['importdataexported'] = 'Exported data from \'from\' course successfully.<br /> Continue to import into your \'to\' course.';
$string['importdatafinished'] = 'Import complete! Continue to your course';
$string['importdatafrom'] = 'Find a course to import data from:';
$string['importinfo'] = 'Import items from other courses, such as activities, blocks or calendar events. No user data will be imported.';
$string['inactive'] = 'Inactive';
$string['include'] = 'Include';
$string['includeallusers'] = 'Include all users';
$string['includecoursefiles'] = 'Include course files';
$string['includecourseusers'] = 'Include course users';
$string['included'] = 'Included';
$string['includelogentries'] = 'Include log entries';
$string['includemodules'] = 'Include modules';
$string['includemoduleuserdata'] = 'Include module user data';
$string['includeneededusers'] = 'Include needed users';
$string['includenoneusers'] = 'Include no users';
$string['includeroleassignments'] = 'Include role assignments';
$string['includesitefiles'] = 'Include site files used in this course';
$string['includesubcategories'] = 'Include subcategories';
$string['includeuserfiles'] = 'Include user files';
$string['increasesections'] = 'Increase the number of sections';
$string['indicator:accessesafterend'] = 'Course accessed after end date';
$string['indicator:accessesafterend_help'] = 'This indicator reflects if the student accessed the course after the course end date.';
$string['indicator:accessesbeforestart'] = 'Course accessed before start date';
$string['indicator:accessesbeforestart_help'] = 'This indicator reflects if the student accessed the course before the course start date.';
$string['indicator:activitiesdue'] = 'Activities due';
$string['indicator:activitiesdue_help'] = 'The user has activities due.';
$string['indicator:anycourseaccess'] = 'Any course access';
$string['indicator:anycourseaccess_help'] = 'This indicator reflects access to any course that the user is enrolled in.';
$string['indicator:anywrite'] = 'Any write action';
$string['indicator:anywrite_help'] = 'This indicator represents any write (submit) action taken by the student.';
$string['indicator:anywriteincourse'] = 'Any write action in the course';
$string['indicator:anywriteincourse_help'] = 'This indicator represents any write (submit) action taken by the student in any course activity.';
$string['indicator:completeduserprofile'] = 'User profile is completed';
$string['indicator:completeduserprofile_help'] = 'This indicator represents that the student has completed their user profile.';
$string['indicator:completeduserprofiledef'] = 'User profile is completed';
$string['indicator:completeduserprofiledef_help'] = 'The site policies have been agreed to and the user has filled in the following fields: Institution, Department, Address, City, Country, URL.';
$string['indicator:completionenabled'] = 'Completion tracking enabled';
$string['indicator:completionenabled_help'] = 'This indicator represents that completion tracking has been enabled for this course.';
$string['indicator:nostudent'] = 'Student enrolments';
$string['indicator:nostudent_help'] = 'This indicator reflects the availability of students in the course.';
$string['indicator:noteacher'] = 'Teacher availability';
$string['indicator:noteacher_help'] = 'This indicator reflects the availability of teachers in the course.';
$string['indicator:potentialcognitive'] = 'Course potential cognitive depth';
$string['indicator:potentialcognitive_help'] = 'This indicator is based on the potential cognitive depth that could be reached by a student participating in course activities.';
$string['indicator:potentialcognitivedef'] = 'Course potential cognitive depth';
$string['indicator:potentialcognitivedef_help'] = 'The degree to which the course offers "deep" cognitive engagement, e.g. submission of work for feedback, the opportunity to review work by others, and the opportunity to revise and resubmit work.';
$string['indicator:potentialcognitivedef_link'] = 'Learning_analytics_indicators#Cognitive_depth';
$string['indicator:potentialsocial'] = 'Course potential social breadth';
$string['indicator:potentialsocial_help'] = 'This indicator is based on the potential social breadth that could be reached by the student participating in course activities.';
$string['indicator:potentialsocialdef'] = 'Course potential social breadth';
$string['indicator:potentialsocialdef_help'] = 'The degree to which the course offers "broad" social engagement, interacting with other participants and with the community of practice beyond the class.';
$string['indicator:potentialsocialdef_link'] = 'Learning_analytics_indicators#Social_breadth';
$string['indicator:readactions'] = 'Read actions amount';
$string['indicator:readactions_help'] = 'This indicator represents the number of read (view) actions taken by the student.';
$string['indicator:userforumstracking'] = 'User is tracking forums';
$string['indicator:userforumstracking_help'] = 'This indicator represents whether or not the student has tracking turned on in the forums.';
$string['info'] = 'Information';
$string['inprogress'] = 'In progress';
$string['insertcontentbefore'] = 'Insert content before \'{$a->activityname}\'';
$string['insertcontentsection'] = 'Insert content in section \'{$a->sectionname}\'';
$string['insertresourceoractivitybefore'] = 'Insert an activity or resource before \'{$a->activityname}\'';
$string['institution'] = 'Institution';
$string['instudentview'] = 'in student view';
$string['interests'] = 'Interests';
$string['interestslist'] = 'List of interests';
$string['interestslist_help'] = 'Enter your interests, one by one, which will then be displayed on your profile page as tags.';
$string['invalidemail'] = 'Invalid email address';
$string['invalidlogin'] = 'Invalid login, please try again';
$string['invalidtaskid'] = 'Invalid task ID';
$string['invalidtaskclassname'] = 'Invalid task class {$a}';
$string['invalidusername'] = 'The username can only contain alphanumeric lowercase characters (letters and numbers), underscore (_), hyphen (-), period (.) or at symbol (@).';
$string['invalidusernameupload'] = 'Invalid username';
$string['ip_address'] = 'IP address';
$string['jump'] = 'Jump';
$string['jumpto'] = 'Jump to...';
$string['keep'] = 'Keep';
$string['labelvalue'] = '{$a->label}: {$a->value}';
$string['langltr'] = 'Language direction left-to-right';
$string['langrtl'] = 'Language direction right-to-left';
$string['language'] = 'Language';
$string['languagegood'] = 'This language pack is up-to-date.';
$string['languageselector'] = 'Language selector';
$string['last'] = 'Last';
$string['lastaccess'] = 'Last access';
$string['lastcourseaccess'] = 'Last access to course';
$string['lastedited'] = 'Last edited';
$string['lastip'] = 'Last IP address';
$string['lastlogin'] = 'Last login';
$string['lastmodified'] = 'Last modified';
$string['lastname'] = 'Last name';
$string['lastnamephonetic'] = 'Last name - phonetic';
$string['lastpage'] = 'Last page';
$string['lastsiteaccess'] = 'Last access to site';
$string['lastyear'] = 'Last year';
$string['latestlanguagepack'] = 'Check for latest language pack on moodle.org';
$string['layouttable'] = 'Layout table';
$string['leavetokeep'] = 'Leave blank to keep current password';
$string['legacylogginginuse'] = 'This site currently has writing to the legacy log store enabled. Writing to this log store is deprecated. Please write to a supported log store such as "standard" or "external".';
$string['legacythemeinuse'] = 'This site is being displayed to you in compatibility mode because your browser is too old.';
$string['license'] = 'Licence';
$string['licenses'] = 'Licences';
$string['liketologin'] = 'Would you like to log in now with a full user account?';
$string['list'] = 'List';
$string['listfiles'] = 'List of files in {$a}';
$string['listofallpeople'] = 'List of all people';
$string['listofcourses'] = 'List of courses';
$string['loading'] = 'Loading';
$string['loadinghelp'] = 'Loading...';
$string['local'] = 'Local';
$string['localplugins'] = 'Local plugins';
$string['localpluginsmanage'] = 'Manage local plugins';
$string['location'] = 'Location';
$string['locktimeout'] = 'The operation timed out while waiting for a lock.';
$string['log_excel_date_format'] = 'yyyy mmmm d h:mm';
$string['loggedinas'] = 'You are logged in as {$a}';
$string['loggedinasguest'] = 'You are currently using guest access';
$string['loggedinnot'] = 'You are not logged in.';
$string['login'] = 'Log in';
$string['loginactivity'] = 'Login activity';
$string['loginalready'] = 'You are already logged in';
$string['loginas'] = 'Log in as';
$string['loginaspasswordexplain'] = '<p>You must enter the special "loginas password" to use this feature.<br />If you do not know it, ask your server administrator.</p>';
$string['login_failure_logs'] = 'Login failure logs';
$string['loginguest'] = 'Access as a guest';
$string['loginsite'] = 'Log in to the site';
$string['loginsteps'] = 'For full access to this site, you first need to create an account.';
$string['loginstepsnone'] = '<p>Hi!</p>
<p>For full access to courses you\'ll need to create yourself an account.</p>
<p>All you need to do is make up a username and password and use it in the form on this page!</p>
<p>If someone else has already chosen your username then you\'ll have to try again using a different username.</p>';
$string['loginto'] = 'Log in to {$a}';
$string['loginagain'] = 'Log in again';
$string['loginrequired'] = 'Login required';
$string['logoof'] = 'Logo of {$a}';
$string['logout'] = 'Log out';
$string['logoutconfirm'] = 'Do you really want to log out?';
$string['logs'] = 'Logs';
$string['logtoomanycourses'] = '[ <a href="{$a->url}">more</a> ]';
$string['logtoomanyusers'] = '[ <a href="{$a->url}">more</a> ]';
$string['lookback'] = 'Look back';
$string['menu'] = 'Menu';
$string['mailadmins'] = 'Inform admins';
$string['mailstudents'] = 'Inform students';
$string['mailteachers'] = 'Inform teachers';
$string['maincoursepage'] = 'Main course page';
$string['makeafolder'] = 'Create folder';
$string['makeavailable'] = 'Make available';
$string['makeeditable'] = 'If you make \'{$a}\' editable by the web server process (eg apache) then you could edit this file directly from this page';
$string['makethismyhome'] = 'Make this my home page';
$string['makeunavailable'] = 'Make unavailable';
$string['managecombined'] = 'Manage course categories and courses';
$string['managecategories'] = 'Manage course categories';
$string['manageblocks'] = 'Blocks';
$string['managecategorythis'] = 'Manage this category';
$string['managecontentbanktypes'] = 'Manage content types';
$string['managecourses'] = 'Manage courses';
$string['managedataformats'] = 'Manage data formats';
$string['managedatabase'] = 'Database';
$string['manageeditorfiles'] = 'Manage files used by editor';
$string['managefilters'] = 'Filters';
$string['managemodules'] = 'Modules';
$string['manageroles'] = 'Roles and permissions';
$string['markallread'] = 'Mark all as read';
$string['match'] = 'Match';
$string['matchingsearchandrole'] = 'Matching \'{$a->search}\' and {$a->role}';
$string['matchofthefollowing'] = 'of the following:';
$string['maxareabytesreached'] = 'The file (or the total size of several files) is larger than the space remaining in this area.';
$string['maxfilesize'] = 'Maximum size for new files: {$a}';
$string['maxfilesreached'] = 'You are allowed to attach a maximum of {$a} file(s) to this item';
$string['maximumchars'] = 'Maximum of {$a} characters';
$string['maximumgrade'] = 'Maximum grade';
$string['maximumgradex'] = 'Maximum grade: {$a}';
$string['maximumshort'] = 'Max';
$string['maximumupload'] = 'Maximum upload size';
$string['maximumupload_help'] = 'The maximum file size allowed for student uploads to the course. Additionally, you can further restrict the maximum upload size for each activity.';
$string['maxlengthreached'] = 'Maximum character limit of {$a} has been reached.';
$string['maxnumberweeks'] = 'Maximum number of sections (deprecated)';
$string['maxnumberweeks_desc'] = 'The maximum value in the number of sections drop-down menu (applies to certain course formats only). This setting is deprecated and will be removed in a future version of Moodle. Please use the course format settings instead.';
$string['maxnumcoursesincombo'] = 'Browse <a href="{$a->link}">{$a->numberofcourses} courses</a>.';
$string['maxsize'] = 'Max size: {$a}';
$string['maxsizeandareasize'] = 'Maximum size for new files: {$a->size}, overall limit: {$a->areasize}';
$string['maxsizeandattachments'] = 'Maximum file size: {$a->size}, maximum number of files: {$a->attachments}';
$string['maxsizeandattachmentsandareasize'] = 'Maximum file size: {$a->size}, maximum number of files: {$a->attachments}, maximum total size: {$a->areasize}';
$string['memberincourse'] = 'People in the course';
$string['message'] = 'Message';
$string['messagebody'] = 'Message body';
$string['messagedselectedusers'] = 'Selected users have been messaged and the recipient list has been reset.';
$string['messagedselectedusersfailed'] = 'Something went wrong while messaging selected users.  Some may have received the email.';
$string['messageprovider:asyncbackupnotification'] = 'Asynchronous backup/restore notifications';
$string['messageprovider:availableupdate'] = 'Available update notifications';
$string['messageprovider:backup'] = 'Backup notifications';
$string['messageprovider:badgecreatornotice'] = 'Badge creator notifications';
$string['messageprovider:badgerecipientnotice'] = 'Badge recipient notifications';
$string['messageprovider:competencyplancomment'] = 'Comment posted on a learning plan';
$string['messageprovider:competencyusercompcomment'] = 'Comment posted on a competency';
$string['messageprovider:coursecompleted'] = 'Course completed';
$string['messageprovider:coursecontentupdated'] = 'Course content changes';
$string['messageprovider:courserequestapproved'] = 'Course creation request approval notification';
$string['messageprovider:courserequested'] = 'Course creation request notification';
$string['messageprovider:courserequestrejected'] = 'Course creation request rejection notification';
$string['messageprovider:enrolcoursewelcomemessage'] = 'Welcome message for new course enrolments';
$string['messageprovider:errors'] = 'Important errors with the site';
$string['messageprovider:errors_help'] = 'These are important errors that an administrator should know about.';
$string['messageprovider:gradenotifications'] = 'Grade notifications';
$string['messageprovider:messagecontactrequests'] = 'Message contact requests notification';
$string['messageprovider:newlogin'] = 'New login notifications';
$string['messageprovider:notices'] = 'Notices about minor problems';
$string['messageprovider:notices_help'] = 'These are notices that an administrator might be interested in seeing.';
$string['messageprovider:infected'] = 'Antivirus failure notifications.';
$string['messageprovider:insights'] = 'Insights generated by prediction models';
$string['messageprovider:instantmessage'] = 'Personal messages between users';
$string['messageprovider:instantmessage_help'] = 'This section configures what happens to messages that are sent to you directly from other users on this site.';
$string['messageprovider:reportbuilderschedule'] = 'Custom report builder schedules';
$string['messageprovider:failedtaskmaxdelay'] = 'Task reaches its maximum fail delay';
$string['messageselect'] = 'Select this user as a message recipient';
$string['messageselectadd'] = 'Send a message';
$string['middlename'] = 'Middle name';
$string['migratinggrades'] = 'Migrating grades';
$string['min'] = 'min';
$string['mins'] = 'mins';
$string['minute'] = 'minute';
$string['minutes'] = 'minutes';
$string['miscellaneous'] = 'Miscellaneous';
$string['missingcategory'] = 'You need to choose a category';
$string['missingdescription'] = 'Missing description';
$string['missingemail'] = 'Missing email address';
$string['missingfirstname'] = 'Missing given name';
$string['missingfromdisk'] = 'Missing from disk';
$string['missingfullname'] = 'Missing full name';
$string['missinglastname'] = 'Missing last name';
$string['missingname'] = 'Missing name';
$string['missingnewpassword'] = 'Missing new password';
$string['missingpassword'] = 'Missing password';
$string['missingrecaptchachallengefield'] = 'Failed reCAPTCHA challenge, try again.';
$string['missingreqreason'] = 'Missing reason';
$string['missingshortname'] = 'Missing short name';
$string['missingshortsitename'] = 'Missing short site name';
$string['missingsitedescription'] = 'Missing site description';
$string['missingsitename'] = 'Missing site name';
$string['missingstrings'] = 'Check for untranslated words or phrases';
$string['missingstudent'] = 'Must choose something';
$string['missingsummary'] = 'Missing summary';
$string['missingteacher'] = 'Must choose something';
$string['missingurl'] = 'Missing URL';
$string['missingusername'] = 'Missing username';
$string['moddoesnotsupporttype'] = 'Module {$a->modname} does not support uploads of type {$a->type}';
$string['modhidden'] = 'Availability';
$string['modhidden_help'] = '* Hide on course page: Not available to students. This module cannot be shown to students.';
$string['modhide'] = 'Hide';
$string['modshow'] = 'Show';
$string['modvisible'] = 'Availability';
$string['modvisible_help'] = '* Show on course page: Available to students (subject to any access restrictions which may be set).
* Hide on course page: Not available to students.';
$string['modvisiblewithstealth'] = 'Availability';
$string['modvisiblewithstealth_help'] = '* Show on course page: Available to students (subject to any access restrictions which may be set).
* Hide on course page: Not available to students.
* Make available but don\'t show on course page: Available to students if you provide a link. Activities will still appear in the gradebook and other reports.';
$string['modvisiblehiddensection'] = 'Availability';
$string['modvisiblehiddensection_help'] = '* Hide on course page: Not available to students.
* Make available but don\'t show on course page: Available to students if you provide a link. Activities will still appear in the gradebook and other reports.';
$string['moodlelogo'] = 'Moodle logo';
$string['month'] = 'Month';
$string['months'] = 'Months';
$string['modified'] = 'Modified';
$string['moduleintro'] = 'Description';
$string['modulesetup'] = 'Setting up module tables';
$string['modulesuccess'] = '{$a} tables have been set up correctly';
$string['modulesused'] = 'Modules used';
$string['moodledocs'] = 'Moodle Docs';
$string['moodledocslink'] = 'Documentation for this page';
$string['moodleversion'] = 'Moodle version';
$string['moodlerelease'] = 'Moodle release';
$string['moodleservicesandsupport'] = 'Services and support';
$string['moodlenet:cannotconnecttoserver'] = 'Cannot connect to MoodleNet server';
$string['moodlenet:columnname'] = 'Name';
$string['moodlenet:columnsenddate'] = 'Send date';
$string['moodlenet:columnsendstatus'] = 'Send status';
$string['moodlenet:columntype'] = 'Type';
$string['moodlenet:configoauthservice'] = 'Select a MoodleNet OAuth 2 service to enable sharing to that MoodleNet site. If the service doesn\'t exist yet, you will need to <a href="{$a}">create</a> it.';
$string['moodlenet:deletedactivity'] = 'Deleted activity';
$string['moodlenet:deletedcourse'] = 'Deleted course';
$string['moodlenet:eventresourceexported'] = 'Resource exported';
$string['moodlenet:gotomoodlenet'] = 'Go to MoodleNet drafts';
$string['moodlenet:issuerisnotauthorized'] = 'MoodleNet issuer is not authorised';
$string['moodlenet:issuerisnotenabled'] = 'MoodleNet issuer is not enabled';
$string['moodlenet:issuerisnotset'] = 'MoodleNet issuer is not set at site administration';
$string['moodlenet:nosharedresources'] = 'There are no shared resources to display at this time.';
$string['moodlenet:outboundsettings'] = 'MoodleNet outbound settings';
$string['moodlenet:sharenoticeactivity'] = 'This activity is being shared with MoodleNet as a resource.';
$string['moodlenet:sharenoticecourse'] = 'This course is being shared with MoodleNet as a resource.';
$string['moodlenet:sharenoticepartial'] = 'The selected activities are being shared with MoodleNet as a resource.';
$string['moodlenet:sharenoticepartialactivitynumber'] = '{$a} activities will be included in the course.';
$string['moodlenet:sharefailtitle'] = 'Something went wrong';
$string['moodlenet:sharefailtext'] = 'There was an error sharing your content to MoodleNet.<br>Please try again later.';
$string['moodlenet:sharefailtextwithsitesupport'] = 'There was an error sharing your content to MoodleNet.<br>Please try again later or <a href="{$a}">contact site support</a>.';
$string['moodlenet:sharefilesizelimitexceeded'] = 'The size of the resource being shared ({$a->filesize} bytes) exceeds the limit of {$a->filesizelimit} bytes.';
$string['moodlenet:shareprogress'] = 'MoodleNet share progress';
$string['moodlenet:shareprogressinfo'] = 'The list shows courses and activities you have shared to MoodleNet.<br>Click the resource name to view in MoodleNet.';
$string['moodlenet:sharesuccesstitle'] = 'Saved to MoodleNet drafts';
$string['moodlenet:sharesuccesstext'] = "Almost done! Visit your drafts in MoodleNet to finish sharing your content.";
$string['moodlenet:sharetomoodlenet'] = 'Share to MoodleNet';
$string['moodlenet:sharingstatus'] = 'Sharing to MoodleNet';
$string['moodlenet:sharinglargefile'] = "Large files can take some time.";
$string['moodlenet:sharingto'] = 'Sharing to: ';
$string['moodlenet:packagingandsending'] = 'Packaging your file and sending to MoodleNet...';
$string['more'] = 'more';
$string['morehelp'] = 'More help';
$string['morehelpaboutmodule'] = 'More help about the {$a} activity';
$string['moreinfo'] = 'More info';
$string['moreinformation'] = 'More information about this error';
$string['moreprofileinfoneeded'] = 'Please tell us more about yourself';
$string['morenavigationlinks'] = 'More...';
$string['mostrecently'] = 'most recently';
$string['move'] = 'Move';
$string['movecoursemodule'] = 'Move activity';
$string['movecoursesection'] = 'Move section';
$string['movecontent'] = 'Move {$a}';
$string['movecontentafter'] = 'After "{$a}"';
$string['movecontenttothetop'] = 'To the top of the list';
$string['movecategorycontentto'] = 'Move into';
$string['movecategorysuccess'] = 'Successfully moved category \'{$a->moved}\' into category \'{$a->to}\'';
$string['movecategoriessuccess'] = 'Successfully moved {$a->count} categories into category \'{$a->to}\'';
$string['movecategorytotopsuccess'] = 'Successfully moved category \'{$a->moved}\' to top level';
$string['movecategoriestotopsuccess'] = 'Successfully moved {$a->count} categories to top level';
$string['movecategoryto'] = 'Move category to:';
$string['movecontentstoanothercategory'] = 'Move contents to another category';
$string['movecourseto'] = 'Move course to:';
$string['movedown'] = 'Move down';
$string['movefilestohere'] = 'Move files to here';
$string['movefull'] = 'Move {$a} to this location';
$string['movehere'] = 'Move to here';
$string['moveitemdown'] = 'Move {$a} down';
$string['moveitemup'] = 'Move {$a} up';
$string['moveleft'] = 'Move left';
$string['moremenu'] = 'More';
$string['moreactions'] = 'More actions';
$string['moveright'] = 'Move right';
$string['movesection'] = 'Move section {$a}';
$string['moveselectedcategoriesto'] = 'Move selected categories to';
$string['moveselectedcoursesto'] = 'Move selected courses to...';
$string['movetoanotherfolder'] = 'Move to another folder';
$string['moveup'] = 'Move up';
$string['multipleitemsfound'] = 'There are {$a} items found.';
$string['mustconfirm'] = 'You need to confirm your account';
$string['mustchangepassword'] = 'The new password must be different than the current one';
$string['mycourses'] = 'My courses';
$string['myfiles'] = 'My private files';
$string['myfilesmanage'] = 'Manage my private files';
$string['myhome'] = 'Dashboard';
$string['mymoodledashboard'] = 'My Moodle dashboard';
$string['myprofile'] = 'My profile';
$string['name'] = 'Name';
$string['namedfiletoolarge'] = 'The file \'{$a->filename}\' is too large and cannot be uploaded';
$string['nameforlink'] = 'What do you want to call this link?';
$string['nameforpage'] = 'Name';
$string['navigation'] = 'Navigation';
$string['needed'] = 'Needed';
$string['networkdropped'] = 'We have detected that your Internet connection is unreliable or has been interrupted.<br />
Please be aware that changes may not be saved properly until your connection improves.';
$string['never'] = 'Never';
$string['neverdeletelogs'] = 'Never delete logs';
$string['new'] = 'New';
$string['newaccount'] = 'New account';
$string['newactivityname'] = 'New name for activity {$a}';
$string['newcourse'] = 'New course';
$string['newloginnotificationtitle'] = 'New sign in to your {$a} account';
$string['newloginnotificationbodysmall'] = 'Your {$a} account was just signed in to from a new device.';
$string['newloginnotificationbodyfull'] = '<p>Hi {$a->userfullname},</p>
<p>Your {$a->sitename} account was just signed in to from a new device.</p>
<ul>
<li>Your account: {$a->username} {$a->useremail}</li>
<li>{$a->logintime}</li>
<li>Device: {$a->logindevice}</li>
<li>IP: {$a->loginip}</li>
</ul>
<p>If this was you, then you don\'t need to do anything.</p>
<p>If you don\'t recognise this activity, please <a href="{$a->changepasswordlink}">change your password</a>.</p>';
$string['newpassword'] = 'New password';
$string['newpassword_help'] = 'Enter a new password or leave blank to keep current password.';
$string['newpasswordfromlost'] = '<strong>NOTICE:</strong> Your <strong>Current password</strong> will have been sent to you in the <strong>second</strong> of the two emails sent as part of the lost password recovery process. Make sure you have received your replacement password before continuing with this screen.';
$string['newpicture'] = 'New picture';
$string['newpicture_help'] = 'To add a new picture, browse and select an image (in JPG or PNG format) then click "Update profile". The image will be cropped to a square and resized to 100x100 pixels.';
$string['newpictureusernotsetup'] = 'A profile picture can only be added once all required profile information has been saved.';
$string['newsectionname'] = 'New name for section {$a}';
$string['newsitem'] = 'news item';
$string['newsitems'] = 'announcements';
$string['newsitemsnumber'] = 'Number of announcements';
$string['newsitemsnumber_help'] = 'The announcements forum has forced subscription set by default. Only teachers and other users with appropriate permission can post in it.

If you don\'t require an announcements forum, set this to zero.

This setting also determines how many recent announcements appear in the latest announcements block.';
$string['newuser'] = 'New user';
$string['newusernewpasswordsubj'] = 'New user account';
$string['newusernewpasswordtext'] = 'Hi {$a->firstname},

An account has been created for you at \'{$a->sitename}\'.

   username: {$a->username}
   password: {$a->newpassword}

(You will be prompted to change your password when you log in for the first time.)

To start using \'{$a->sitename}\', log in at
   {$a->link}

If you need help, contact the site administrator,
{$a->signoff}';
$string['newusers'] = 'New users';
$string['newwindow'] = 'New window';
$string['next'] = 'Next';
$string['nextpage'] = 'Next page';
$string['nextsection'] = 'Next section';
$string['no'] = 'No';
$string['noblockstoaddhere'] = 'There are no blocks that you can add to this page.';
$string['nobody'] = 'Nobody';
$string['nocourses'] = 'No courses';
$string['nocoursesfound'] = 'No courses were found with the words \'{$a}\'';
$string['nocoursestarttime'] = 'The course does not have a start date.';
$string['nocoursesyet'] = 'No courses in this category';
$string['nocomments'] = 'No comments';
$string['nodstpresets'] = 'The administrator has not enabled Daylight Savings Time support.';
$string['nofilesselected'] = 'No files have been selected to restore';
$string['nofilesyet'] = 'No files have been uploaded to your course yet';
$string['nofiltersapplied'] = 'No filters applied';
$string['nograde'] = 'No grade';
$string['nohelpforactivityorresource'] = 'There is currently no help associated with this resource or activity';
$string['nochange'] = 'No change';
$string['noimagesyet'] = 'No images have been uploaded to your course yet';
$string['noitemsfound'] = 'No items found.';
$string['nologsfound'] = 'No logs have been found';
$string['nomatchingusers'] = 'No users match \'{$a}\'';
$string['nomorecourses'] = 'No more matching courses could be found';
$string['nomoreidnumber'] = 'Not using an idnumber to avoid collisions';
$string['none'] = 'None';
$string['noneditingteacher'] = 'Non-editing teacher';
$string['noneditingteacherdescription'] = 'Non-editing teachers can teach in courses and grade students, but may not alter activities.';
$string['nonstandard'] = 'Non-standard';
$string['noresultsfor'] = 'No results for "{$a}"';
$string['noresultsfor_help'] = 'Check your spelling or try different words.';
$string['nopendingcourses'] = 'There are no courses pending approval';
$string['nopotentialadmins'] = 'No potential admins';
$string['nopotentialcreators'] = 'No potential course creators';
$string['nopotentialstudents'] = 'No potential students';
$string['nopotentialteachers'] = 'No potential teachers';
$string['norecentactivity'] = 'No recent activity';
$string['noreplyname'] = 'Do not reply to this email';
$string['noresetrecord'] = 'There is no record of that reset request. Please initiate a new password reset request.';
$string['noresults'] = 'No results';
$string['normal'] = 'Normal';
$string['normalfilter'] = 'Normal search';
$string['nosite'] = 'Could not find site-level course';
$string['nostudentsfound'] = 'No {$a} found';
$string['nostudentsingroup'] = 'There are no students in this group yet';
$string['nostudentsyet'] = 'There are no students enrolled in this course.';
$string['nosuchemail'] = 'No such email address';
$string['notavailable'] = 'Not available';
$string['notavailablecourse'] = '{$a} is not available';
$string['noteachersyet'] = 'No teachers in this course yet';
$string['noteachingupcomingcourses'] = 'Upcoming courses have no teachers or students';
$string['notenrolled'] = '{$a} is not enrolled in this course.';
$string['notenrolledprofile'] = 'This profile is not available because this user is not enrolled in this course.';
$string['noteusercannotrolldatesoncontext'] = '<strong>Note:</strong> The ability to roll dates when restoring this backup has been disabled because you lack the required permissions.';
$string['noteuserschangednonetocourse'] = '<strong>Note:</strong> Course users need to be restored when restoring user data (in activities, files or messages). This setting has been changed for you.';
$string['nothingnew'] = 'No recent activity';
$string['nothingtodisplay'] = 'Nothing to display';
$string['notice'] = 'Notice';
$string['noticenewerbackup'] = 'This backup file has been created with Moodle {$a->backuprelease} ({$a->backupversion}) and it\'s newer than your currently installed Moodle {$a->serverrelease} ({$a->serverversion}). This could cause some inconsistencies because backwards compatibility of backup files cannot be guaranteed.';
$string['notifications'] = 'Notifications';
$string['notifyloginfailuresmessage'] = '{$a->time}, IP: {$a->ip}, User: {$a->info}, User full name: {$a->name}';
$string['notifyloginfailuresmessageend'] = 'You can view these logs at {$a}';
$string['notifyloginfailuresmessagestart'] = 'Here is a list of failed login attempts at {$a} since you were last notified';
$string['notifyloginfailuressubject'] = '{$a} :: Failed logins notification';
$string['notincluded'] = 'Not included';
$string['notingroup'] = 'Sorry, but you need to be part of a group to see this page.';
$string['notpublic'] = 'Not public!';
$string['nousersfound'] = 'No users found';
$string['nousersmatching'] = 'No users matching \'{$a}\' were found';
$string['nousersyet'] = 'There are no users yet';
$string['novalidcourses'] = 'No valid courses to be shown';
$string['now'] = 'now';
$string['numattempts'] = '{$a} failed login attempt(s)';
$string['numberofcourses'] = 'Number of courses';
$string['numberweeks'] = 'Number of sections';
$string['numday'] = '{$a} day';
$string['numdays'] = '{$a} days';
$string['numhours'] = '{$a} hours';
$string['numletters'] = '{$a} letters';
$string['numminutes'] = '{$a} minutes';
$string['nummonth'] = '{$a} month';
$string['nummonths'] = '{$a} months';
$string['numseconds'] = '{$a} seconds';
$string['numviews'] = '{$a} views';
$string['numweek'] = '{$a} week';
$string['numweeks'] = '{$a} weeks';
$string['numwords'] = '{$a} words';
$string['numyear'] = '{$a} year';
$string['numyears'] = '{$a} years';
$string['ok'] = 'OK';
$string['oldpassword'] = 'Current password';
$string['olduserdirectory'] = 'This is the OLD users directory, and is no longer needed. You may safely delete it. The files it contains have been copied to the NEW user directory.';
$string['oneitemfound'] = 'There is 1 item found.';
$string['opendrawerblocks'] = 'Open block drawer';
$string['opendrawerindex'] = 'Open course index';
$string['opensinnewwindow'] = 'Opens in new window';
$string['opensinnewwindowbracketed'] = '(Opens in new window)';
$string['operator_and'] = 'and';
$string['operator_andnot'] = 'and';
$string['operator_or'] = 'or';
$string['optional'] = 'optional';
$string['options'] = 'options';
$string['order'] = 'Order';
$string['originalpath'] = 'Original path';
$string['orphanedactivitiesinsectionno'] = 'Orphaned activities (section {$a})';
$string['other'] = 'Other';
$string['outline'] = 'Outline';
$string['outlinereport'] = 'Outline report';
$string['page'] = 'Page';
$string['pagea'] = 'Page {$a}';
$string['pagedcontentnavigation'] = 'Pagination navigation';
$string['pagedcontentnavigationitem'] = 'Go to page {$a}';
$string['pagedcontentnavigationactiveitem'] = 'Current page, page {$a}';
$string['pagedcontentpagingbaritemsperpage'] = 'Show {$a} items per page';
$string['pageheaderconfigablock'] = 'Configuring a block in {$a->fullname}';
$string['pagepath'] = 'Page path';
$string['pageshouldredirect'] = 'This page should automatically redirect. If nothing is happening please use the continue link below.';
$string['parentcategory'] = 'Parent category';
$string['parentcoursenotfound'] = 'Parent course not found!';
$string['parentfolder'] = 'Parent folder';
$string['participants'] = 'Participants';
$string['participantslist'] = 'Participants list';
$string['participationratio'] = 'Participation ratio';
$string['participationreport'] = 'Participation report';
$string['password'] = 'Password';
$string['passwordextlink'] = 'The following link has been provided to recover your lost password. This will take you out of Moodle.';
$string['passwordforgotten'] = 'Forgotten password';
$string['passwordforgotteninstructions'] = 'Your details must first be found in the user database. Please enter <strong>either</strong> your username or your registered email address in the appropriate box. There is no need to enter both.';
$string['passwordforgotteninstructions2'] = 'To reset your password, submit your username or your email address below. If we can find you in the database, an email will be sent to your email address, with instructions how to get access again.';
$string['passwordchanged'] = 'Password has been changed';
$string['passwordpolicynomatch'] = 'Your current password no longer matches the set password policy.
   {$a}';
$string['passwordsdiffer'] = 'These passwords do not match';
$string['passwordset'] = 'Your password has been set.';
$string['path'] = 'Path';
$string['pathnotexists'] = 'Path doesn\'t exist in your server!';
$string['pathslasherror'] = 'The path can\'t end with a slash.';
$string['paymentinstant'] = 'Use the button below to pay and be enrolled within minutes.';
$string['paymentpending'] = '(<small><b><u>{$a}</u></b> pending</small>)';
$string['paymentrequired'] = 'This course requires a payment for entry';
$string['payments'] = 'Payments';
$string['paymentsorry'] = 'Thanks for your payment. When it is processed, you will be able to enter the course {$a->fullname}.  Please wait then try again. If you continue to have trouble, contact the {$a->teacher} or the site administrator.';
$string['paymentthanks'] = 'Thanks for your payment. You are now enrolled in the course {$a}.';
$string['pendingrequests'] = 'Pending requests';
$string['percents'] = '{$a}%';
$string['periodending'] = 'Period ending ({$a})';
$string['perpage'] = 'Per page';
$string['perpagea'] = 'Per page: {$a}';
$string['personal'] = 'Personal';
$string['personalprofile'] = 'Personal profile';
$string['phone'] = 'Phone';
$string['phone1'] = 'Phone';
$string['phone2'] = 'Mobile phone';
$string['phpinfo'] = 'PHP info';
$string['picture'] = 'Picture';
$string['pictureof'] = 'Picture of {$a}';
$string['pictureofuser'] = 'User picture';
$string['placeholdertypeorselect'] = 'Type or select...';
$string['pleaseclose'] = 'Please close this window now.';
$string['pleasesearchmore'] = 'Please search some more';
$string['pleaseusesearch'] = 'Please use the search';
$string['plugin'] = 'Plugin';
$string['pluginarea'] = 'Area';
$string['plugindeletefiles'] = 'All data associated with the plugin \'{$a->name}\' has been deleted from the database. To prevent the plugin re-installing itself, you should now delete this directory from your server: {$a->directory}';
$string['plugincheck'] = 'Plugins check';
$string['pluginitemid'] = 'Item ID';
$string['pluginmissingfromdisk'] = '{$a->name} (Missing from disk)';
$string['pluginsetup'] = 'Setting up plugin tables';
$string['policyaccept'] = 'I understand and agree';
$string['policyagree'] = 'You must agree to this policy to continue using this site.  Do you agree?';
$string['policyagreement'] = 'Site policy agreement';
$string['policyagreementclick'] = 'Site policy agreement';
$string['popup'] = 'popup';
$string['popupwindow'] = 'Open file in new window';
$string['popupwindowname'] = 'Popup window';
$string['post'] = 'Post';
$string['posts'] = 'Posts';
$string['potentialadmins'] = 'Potential admins';
$string['potentialcreators'] = 'Potential course creators';
$string['potentialstudents'] = 'Potential students';
$string['potentialteachers'] = 'Potential teachers';
$string['poweredbymoodle'] = 'Powered by <a href="https://moodle.com">Moodle</a>';
$string['preferences'] = 'Preferences';
$string['preferredlanguage'] = 'Preferred language';
$string['preferredtheme'] = 'Preferred theme';
$string['preprocessingbackupfile'] = 'Preprocessing backup file';
$string['prev'] = 'Prev';
$string['preview'] = 'Preview';
$string['previeworchoose'] = 'Preview or choose a theme';
$string['previewthemename'] = 'Preview theme \'{$a}\'';
$string['previous'] = 'Previous';
$string['previouslyselectedusers'] = 'Previously selected users not matching \'{$a}\'';
$string['previouspage'] = 'Previous page';
$string['previoussection'] = 'Previous section';
$string['primaryadminsetup'] = 'Setup administrator account';
$string['privacy:metadata:config_log'] = 'The log of configuration changes.';
$string['privacy:metadata:config_log:name'] = 'The name of the setting changes.';
$string['privacy:metadata:config_log:oldvalue'] = 'The previous value for this setting.';
$string['privacy:metadata:config_log:plugin'] = 'The plugin modified.';
$string['privacy:metadata:config_log:timemodified'] = 'The time that the change was made.';
$string['privacy:metadata:config_log:userid'] = 'The user who made the change.';
$string['privacy:metadata:config_log:value'] = 'The  new value for this setting.';
$string['privacy:metadata:events_queue'] = 'The queue of user events waiting to be processed.';
$string['privacy:metadata:events_queue:eventdata'] = 'The data stored in the event.';
$string['privacy:metadata:events_queue:stackdump'] = 'Any stacktrace associated with this event.';
$string['privacy:metadata:events_queue:timecreated'] = 'The time that this event was created.';
$string['privacy:metadata:events_queue:userid'] = 'The user ID associated with this event';
$string['privacy:metadata:log'] = 'A collection of past events';
$string['privacy:metadata:log:action'] = 'A description of the action';
$string['privacy:metadata:log:cmid'] = 'cmid';
$string['privacy:metadata:log:course'] = 'course';
$string['privacy:metadata:log:info'] = 'Additional information';
$string['privacy:metadata:log:ip'] = 'The IP address used at the time of the event';
$string['privacy:metadata:log:module'] = 'module';
$string['privacy:metadata:log:time'] = 'The time when the action took place';
$string['privacy:metadata:log:url'] = 'The URL related to the event';
$string['privacy:metadata:log:userid'] = 'The ID of the user who performed the action';
$string['privacy:metadata:moodlenet_share_progress'] = 'MoodleNet share progress details';
$string['privacy:metadata:moodlenet_share_progress:type'] = 'The type of share that was performed';
$string['privacy:metadata:moodlenet_share_progress:courseid'] = 'The associated course ID';
$string['privacy:metadata:moodlenet_share_progress:cmid'] = 'The associated course module ID';
$string['privacy:metadata:moodlenet_share_progress:userid'] = 'The user that performed the share';
$string['privacy:metadata:moodlenet_share_progress:timecreated'] = 'The time the share was performed';
$string['privacy:metadata:moodlenet_share_progress:resourceurl'] = 'The returned URL from MoodleNet after a successful share';
$string['privacy:metadata:moodlenet_share_progress:status'] = 'The resulting status of the share';
$string['privacy:metadata:oauth2_refresh_token'] = 'Refresh token used in OAuth 2.0 communication';
$string['privacy:metadata:oauth2_refresh_token:issuerid'] = 'The ID of the issuer to which the token corresponds';
$string['privacy:metadata:oauth2_refresh_token:scopehash'] = 'The ID of the user to whom the token corresponds';
$string['privacy:metadata:oauth2_refresh_token:token'] = 'The refresh token for the respective scopes and user';
$string['privacy:metadata:oauth2_refresh_token:timecreated'] = 'The time when the token was created';
$string['privacy:metadata:oauth2_refresh_token:timemodified'] = 'The time when the token was last updated';
$string['privacy:metadata:oauth2_refresh_token:userid'] = 'The ID of the user to whom the token corresponds';
$string['privacy:metadata:shortlink'] = 'Shortlink URL details';
$string['privacy:metadata:shortlink:shortcode'] = 'The shortcode to use for the shortlink';
$string['privacy:metadata:shortlink:userid'] = 'The ID of the user associated with the shortlink';
$string['privacy:metadata:shortlink:component'] = 'The component associated with the shortlink';
$string['privacy:metadata:shortlink:linktype'] = 'The type of link the shortlink can be identified as';
$string['privacy:metadata:shortlink:identifier'] = 'The unique identifier associated with the shortlink';
$string['privacy:metadata:task_adhoc'] = 'The status of ad hoc tasks.';
$string['privacy:metadata:task_adhoc:component'] = 'The component owning the task.';
$string['privacy:metadata:task_adhoc:nextruntime'] = 'The earliest time to run this task.';
$string['privacy:metadata:task_adhoc:userid'] = 'The user to run the task as.';
$string['privacy:metadata:task_log'] = 'Log output for a log';
$string['privacy:metadata:task_log:component'] = 'The component owning the task.';
$string['privacy:metadata:task_log:userid'] = 'The user that the task belonged to.';
$string['privacy:metadata:upgrade_log'] = 'The upgrade log.';
$string['privacy:metadata:upgrade_log:backtrace'] = 'Any backtrace associated with this upgrade step.';
$string['privacy:metadata:upgrade_log:details'] = 'Extra information relating to the upgrade.';
$string['privacy:metadata:upgrade_log:info'] = 'The main information for this upgrade step.';
$string['privacy:metadata:upgrade_log:plugin'] = 'The plugin which was upgraded.';
$string['privacy:metadata:upgrade_log:targetversion'] = 'The new version to upgrade to.';
$string['privacy:metadata:upgrade_log:timemodified'] = 'The time that the upgrade took place.';
$string['privacy:metadata:upgrade_log:type'] = 'The type of log entry.';
$string['privacy:metadata:upgrade_log:userid'] = 'The user who ran the upgrade.';
$string['privacy:metadata:upgrade_log:version'] = 'The old version of the plugin.';
$string['privatefiles'] = 'Private files';
$string['privatefilesmanage'] = 'Manage private files';
$string['private_files_handler'] = 'Store attachments to an e-mail in the user\'s private files storage space.';
$string['private_files_handler_name'] = 'Email to Private files';
$string['proceed'] = 'Proceed';
$string['profile'] = 'Profile';
$string['profilenotshown'] = 'This profile description will not be shown until this person is enrolled in at least one course.';
$string['progress'] = 'Progress';
$string['publicprofile'] = 'Public profile';
$string['publicsitefileswarning'] = 'Note: files placed here can be accessed by anyone';
$string['publicsitefileswarning2'] = 'Note: Files placed here can be accessed by anyone who knows (or can guess) the URL. For security reasons, it is recommended that any backup files are deleted immediately after restoring them.';
$string['publicsitefileswarning3'] = 'Note: Files placed here can be accessed by anyone who knows (or can guess) the URL. <br />For security reasons, backup files should be saved in the secure backupdata folder only.';
$string['question'] = 'Question';
$string['questionsinthequestionbank'] = 'Questions in the question bank';
$string['queued'] = 'Queued';
$string['quotausage'] = 'You have currently used {$a->used} of your {$a->total} limit.';
$string['readinginfofrombackup'] = 'Reading info from backup';
$string['readme'] = 'README';
$string['recentactivity'] = 'Recent activity';
$string['recentactivityreport'] = 'Full report of recent activity...';
$string['recipientslist'] = 'Recipients list';
$string['recommended'] = 'Recommended';
$string['recreatedcategory'] = 'Recreated category {$a}';
$string['redirect'] = 'Redirect';
$string['reducesections'] = 'Reduce the number of sections';
$string['refresh'] = 'Refresh';
$string['refreshingevents'] = 'Refreshing events';
$string['registration'] = 'Moodle registration';
$string['registrationcontact'] = 'Contact from the public';
$string['registrationemail'] = 'Email notifications';
$string['registrationinfo'] = '<p>This page allows you to register your Moodle site with moodle.org.  Registration is free.
The main benefit of registering is that you will be added to a low-volume mailing list
for important notifications such as security alerts and new releases of Moodle.</p>
<p>By default, your information will be kept private, and will never be sold or passed on to anyone else.  The only
   reason for collecting this information is for support purposes, and to help build up a statistical
   picture of the Moodle community as a whole.</p>
<p>If you choose, you can allow your site name, country and URL to be added to the public list of Moodle Sites.</p>
<p>All new registrations are verified manually before they are added to the list, but once you are added you can update your registration (and your entry on the public list) at any time by resubmitting this form.</p>';
$string['registrationinfotitle'] = 'Registration information';
$string['registrationsend'] = 'Send registration information to moodle.org';
$string['registrationyes'] = 'Yes, notify me of new Moodle releases, security alerts and other important news';
$string['reject'] = 'Reject';
$string['rejectdots'] = 'Reject...';
$string['relativedatesmode'] = 'Relative dates mode';
$string['relativedatesmode_help'] = 'Display course or activity dates relative to the user\'s start date in the course.

The user\'s course start date will be their enrolment start date, unless they are enrolled before the course begins in which case their start date will be the course start date.

WARNING: This is an experimental feature and not all activities may support it. Once the course has been created, this course setting can no longer be changed.';
$string['relativedatesmode_warning'] = '<strong>Warning:</strong> Relative dates mode cannot be changed once the course has been created.';
$string['reload'] = 'Reload';
$string['remoteappuser'] = 'Remote {$a} User';
$string['remove'] = 'Remove';
$string['removeadmin'] = 'Remove admin';
$string['removecreator'] = 'Remove course creator';
$string['removed'] = 'Removed {$a}';
$string['removestudent'] = 'Remove student';
$string['removeteacher'] = 'Remove teacher';
$string['rename'] = 'Rename';
$string['renamefileto'] = 'Rename <b>{$a}</b> to';
$string['report'] = 'Report';
$string['reports'] = 'Reports';
$string['reporttype'] = 'Report type';
$string['repositories'] = 'Repositories';
$string['requestcourse'] = 'Request a course';
$string['requestedby'] = 'Requested by';
$string['requestedcourses'] = 'Requested courses';
$string['requestreason'] = 'Reason for course request';
$string['requests'] = 'Requests';
$string['required'] = 'Required';
$string['requirespayment'] = 'This course requires payment for access';
$string['resendemail'] = 'Resend confirmation email';
$string['reset'] = 'Reset';
$string['resetcomponent'] = 'Component';
$string['resetcourse'] = 'Reset course';
$string['resetcourseconfirm'] = 'Reset course?';
$string['resetcoursewarning'] = 'Are you sure you want to reset the course \'{$a}\'?
<br/><br/>
This will delete the selected data and reset the course back to its original state. You can\'t undo this action.';
$string['resetinfo'] = 'This feature allows you to clear all user data and reset the course to its original state. Course activities and settings remain unchanged.';
$string['resetinfoselect'] = 'Select the data you want to delete or reset from the categories below:';
$string['resetnotimplemented'] = 'Reset not supported';
$string['resetnotimplementedinfo'] = 'These activities can\'t be reset:';
$string['resetrecordexpired'] = 'The password reset link you used is more than {$a} minutes old and has expired. Please initiate a new password reset.';
$string['resetstartdate'] = 'Reset start date';
$string['resetstatus'] = 'Status';
$string['resettable'] = 'Reset table preferences';
$string['resettask'] = 'Reset';
$string['resettodefaults'] = 'Reset to defaults';
$string['resortsubcategoriesby'] = 'Sort subcategories by {$a} ascending';
$string['resortsubcategoriesbyreverse'] = 'Sort subcategories by {$a} descending';
$string['resortcourses'] = 'Sort courses';
$string['resource'] = 'Resource';
$string['resource_type'] = 'Resource type';
$string['resourcedisplayauto'] = 'Automatic';
$string['resourcedisplaydownload'] = 'Force download';
$string['resourcedisplayembed'] = 'Embed';
$string['resourcedisplayframe'] = 'In frame';
$string['resourcedisplaynew'] = 'New window';
$string['resourcedisplayopen'] = 'Open';
$string['resourcedisplaypopup'] = 'In pop-up';
$string['resources'] = 'Resources';
$string['resultsfound'] = '{$a} results found';
$string['restore'] = 'Restore';
$string['restorecancelled'] = 'Restore cancelled';
$string['restorecannotassignroles'] = 'Restore needs to assign roles and you do not have permission to do so';
$string['restorecannotcreateorassignroles'] = 'Restore needs to create or assign roles and you do not have permission to do so';
$string['restorecannotcreateuser'] = 'Restore needs to create user \'{$a}\' from backup file and you do not have permission to do so';
$string['restoremnethostidmismatch'] = 'MNet host id of user \'{$a}\' does not match local MNet host ID.';
$string['restorecannotoverrideperms'] = 'Restore needs to override permissions and you do not have permission to do so';
$string['restorecoursenow'] = 'Restore this course now!';
$string['restoredaccount'] = 'Restored account';
$string['restoredaccountinfo'] = 'This account was imported from another server and the password has been lost. To set a new password by email, please click "Continue"';
$string['restorefinished'] = 'Restore completed successfully';
$string['restoreinfo'] = 'Use a backup file to restore a previous version of a course, or to create a new course.';
$string['restoreto'] = 'Restore to';
$string['restoretositeadding'] = 'Warning: You are about to restore to the site home, adding data to it!';
$string['restoretositedeleting'] = 'Warning: You are about to restore to the site home, deleting data from it first!';
$string['restoreuserconflict'] = 'Trying to restore user \'{$a}\' from backup file will cause conflict';
$string['restoreuserinfofailed'] = 'The restore process has stopped because you don\'t have permission to restore user data.';
$string['restoreusersprecheck'] = 'Checking user data';
$string['restoreusersprecheckerror'] = 'Some problems were detected when checking user data';
$string['restricted'] = 'Restricted';
$string['retry'] = 'Retry';
$string['returningtosite'] = 'Returning to this web site?';
$string['returntooriginaluser'] = 'Return to {$a}';
$string['revert'] = 'Revert';
$string['role'] = 'Role';
$string['roleassignments'] = 'Role assignments';
$string['rolemappings'] = 'Role mappings';
$string['rolerenaming'] = 'Role renaming';
$string['rolerenaming_help'] = 'Change the display names of roles in this course.';
$string['rolerenaming_success'] = 'Course role names updated.';
$string['roles'] = 'Roles';
$string['rss'] = 'RSS';
$string['rssarticles'] = 'Number of RSS recent articles';
$string['rsserror'] = 'Error reading RSS data';
$string['rsserrorauth'] = 'Your RSS link does not contain a valid authentication token.';
$string['rsserrorguest'] = 'This feed uses guest access to access the data, but guest does not have permission to read the data. Visit the original location that this feed comes from (URL) as a valid user and get a new RSS link from there.';
$string['rsskeyshelp'] = '<p>To ensure security and privacy, RSS feed URLs contain a special token that identifies the user they are for. This prevents other users from accessing areas of the site where they are not allowed.</p><p>The token is automatically created the first time you access an area that produces an RSS feed. If you think that your RSS feed token has been compromised, you can request a new one by clicking the reset link. Please note that your current RSS feed URLs will then become invalid.</p>';
$string['rsstype'] = 'RSS feed for this activity';
$string['save'] = 'Save';
$string['saveandnext'] = 'Save and show next';
$string['savedat'] = 'Saved at:';
$string['savechanges'] = 'Save changes';
$string['savechangesanddisplay'] = 'Save and display';
$string['savechangesandreturn'] = 'Save and return';
$string['savechangesandreturntocourse'] = 'Save and return to course';
$string['savecomment'] = 'Save comment';
$string['savepreferences'] = 'Save preferences';
$string['saveto'] = 'Save to';
$string['scale'] = 'Scale';
$string['scale_help'] = 'A scale provides a way of evaluating or grading performance in an activity. It is defined by an ordered list of values, ranging from negative to positive, separated by commas, for example "Disappointing, Not good enough, Average, Good, Very good, Excellent!"';
$string['scale_link'] = 'grade/scale';
$string['scales'] = 'Scales';
$string['scalescustom'] = 'Custom scales';
$string['scalescustomcreate'] = 'Add a new scale';
$string['scalescustomno'] = 'No custom scales have been created yet';
$string['scalesstandard'] = 'Standard scales';
$string['scalestandard'] = 'Standard scale';
$string['scalestandard_help'] = 'A standard scale is available site-wide, for all courses.';
$string['scalestandard_link'] = 'grade/scale';
$string['scalestip'] = 'To create custom scales, use the \'Scales...\' link in your course administration menu.';
$string['scalestip2'] = 'To create custom scales, click the Grades link in the course administration menu, then choose Edit, Scales.';
$string['screenshot'] = 'Screenshot';
$string['search'] = 'Search'; // TODO MDL-34652 rename to searchforums and move to mod_forum.
$string['search_help'] = 'For basic searching of one or more words anywhere in the text, just type them separated by spaces. All words longer than two characters are used.

For advanced searching, press the search button without typing anything in the search box to access the advanced search form.';
$string['searchagain'] = 'Search again';
$string['searchactivities'] = 'Search for activities by name or description';
$string['searchbyemail'] = 'Search by email address';
$string['searchbyusername'] = 'Search by username';
$string['searchcoursecategories'] = 'Search categories';
$string['searchcourses'] = 'Search courses';
$string['searchgroups'] = 'Search groups';
$string['searchitems'] = 'Search items';
$string['searchoptions'] = 'Search options';
$string['searchresults'] = 'Search results';
$string['searchusers'] = 'Search users';
$string['sec'] = 'sec';
$string['secondsleft'] = '{$a} secs';
$string['seconds'] = 'seconds';
$string['secondstotime172800'] = '2 days';
$string['secondstotime259200'] = '3 days';
$string['secondstotime345600'] = '4 days';
$string['secondstotime432000'] = '5 days';
$string['secondstotime518400'] = '6 days';
$string['secondstotime604800'] = '1 week';
$string['secondstotime86400'] = '1 day';
$string['secretalreadyused'] = 'Change password confirmation link was already used, password was not changed.';
$string['secs'] = 'secs';
$string['section'] = 'Section';
$string['sectionactionnotsupported'] = 'Section action "{$a}" is not supported here';
$string['subsectionmoveerror'] = 'Cannot move this subsection on another subsection';
$string['sectionname'] = 'Section name';
$string['sectionoutline'] = 'Section outline';
$string['sections'] = 'Sections';
$string['seealsostats'] = 'See also: stats';
$string['select'] = 'Select';
$string['selectacategory'] = 'Please select a category';
$string['selectacountry'] = 'Select a country';
$string['selectacourse'] = 'Select a course';
$string['selectacoursesite'] = 'Select a course or site';
$string['selectanaction'] = 'Select an action';
$string['selectagroup'] = 'Select a group';
$string['selectaregion'] = 'Select a region';
$string['selctauser'] = 'Select a user';
$string['selectall'] = 'Select all';
$string['selectallusersonpage'] = 'Select all users on this page';
$string['selectalluserswithcount'] = 'Select all {$a} users';
$string['selectamodule'] = 'Please select an activity module';
$string['selectanoptions'] = 'Select an option';
$string['selectdates'] = 'Select dates';
$string['selectdefault'] = 'Select default';
$string['selectedfile'] = 'Selected file';
$string['selectedcategories'] = 'Selected categories';
$string['selectednowmove'] = '{$a} files selected for moving. Now go into the destination folder and press \'Move files to here\'';
$string['selectfiles'] = 'Select files';
$string['selectfiltertype'] = 'Select';
$string['selectgroupsseparate'] = 'Select separate groups';
$string['selectgroupsvisible'] = 'Select visible groups';
$string['selectitem'] = 'Select \'{$a}\'';
$string['selectmoduletoviewhelp'] = 'Select an activity or resource to view its help.

Double-click on an activity or resource name to quickly add it.';
$string['selectnos'] = 'Select all \'No\'';
$string['selectperiod'] = 'Select period';
$string['selectcategorysort'] = 'Which categories would you like to sort?';
$string['selectcategorysortby'] = 'Select how you would like to sort categories';
$string['selectcoursesortby'] = 'Select how you would like to sort courses';
$string['selecttheme'] = 'Select theme';
$string['selectthemename'] = 'Select theme \'{$a}\'';
$string['senddetails'] = 'Send my details via email';
$string['sent'] = 'Sent';
$string['separate'] = 'Separate';
$string['separateandconnected'] = 'Separate and Connected ways of knowing';
$string['separateandconnected1'] = 'Mostly separate knowing';
$string['separateandconnected2'] = 'Separate and connected';
$string['separateandconnected3'] = 'Mostly connected knowing';
$string['separateandconnectedinfo'] = 'The scale based on the theory of separate and connected knowing. This theory describes two different ways that we can evaluate and learn about the things we see and hear.<ul><li><strong>Separate knowers</strong> remain as objective as possible without including feelings and emotions. In a discussion with other people, they like to defend their own ideas, using logic to find holes in opponent\'s ideas.</li><li><strong>Connected knowers</strong> are more sensitive to other people. They are skilled at empathy and tend to listen and ask questions until they feel they can connect and "understand things from their point of view". They learn by trying to share the experiences that led to the knowledge they find in other people.</li></ul>';
$string['servererror'] = 'An error occurred whilst communicating with the server';
$string['serverlocaltime'] = 'Server\'s local time';
$string['sessionforceclean'] = 'As a security precaution, user-generated scripts have been disabled within this session.';
$string['sessiontimeoutsoon'] = 'Your session is about to time out. Do you want to extend your current session?';
$string['setcategorytheme'] = 'Set category theme';
$string['setmode'] = 'Set mode';
$string['setpassword'] = 'Set password';
$string['setpasswordinstructions'] = 'Please enter your new password below, then save changes.';
$string['settings'] = 'Settings';
$string['share'] = 'Share';
$string['shortname'] = 'Short name'; /* @deprecated MDL-34652 - Use shortnamecourse or shortnameuser or some own context specific string. */
$string['shortnamecollisionwarning'] = '[*] = This shortname is already in use by a course and will need to be changed upon approval';
$string['shortnamecourse'] = 'Course short name';
$string['shortnamecourse_help'] = 'The name displayed in areas with limited space. It must be unique.';
$string['shortnametaken'] = 'Short name is already used for another course ({$a})';
$string['shortnameuser'] = 'User short name';
$string['shortsitename'] = 'Short name for site (eg single word)';
$string['show'] = 'Show';
$string['showactions'] = 'Show actions';
$string['showactivitydates'] = 'Show activity dates';
$string['showactivitydates_help'] = 'Show activity dates on the course page.';
$string['showadvancededitor'] = 'Advanced';
$string['showadvancedsettings'] = 'Show advanced settings';
$string['showall'] = 'Show all {$a}';
$string['showallcourses'] = 'Show all courses';
$string['showblockcourse'] = 'Show list of courses containing block';
$string['showcategory'] = 'Show {$a}';
$string['showchartdata'] = 'Show chart data';
$string['showcomments'] = 'Show/hide comments';
$string['showcommentsnonjs'] = 'Show comments';
$string['showdescription'] = 'Display description on course page';
$string['showdescription_help'] = 'If enabled, the description above will be displayed on the course page just below the link to the activity or resource.';
$string['showgrades'] = 'Show gradebook to students';
$string['showgrades_help'] = 'Allow students to view a list of all their grades in the course.';
$string['showingacourses'] = 'Showing all {$a} courses';
$string['showingxofycourses'] = 'Showing courses {$a->start} to {$a->end} of {$a->total} courses';
$string['showless'] = 'Show less';
$string['showlistofcourses'] = 'Show list of courses';
$string['showmodulecourse'] = 'Show list of courses containing activity';
$string['showmore'] = 'Show more';
$string['showoncoursepage'] = 'Show on course page';
$string['showonly'] = 'Show only';
$string['showperpage'] = 'Show {$a} per page';
$string['showpopovermenu'] = 'Open popover';
$string['showpopoverwindow'] = 'Show popover window';
$string['showrecent'] = 'Show recent activity';
$string['showreports'] = 'Show activity reports';
$string['showreports_help'] = 'Allow students to view their own activity reports via their profile page.';
$string['showsettings'] = 'Show settings';
$string['showtheselogs'] = 'Show these logs';
$string['showthishelpinlanguage'] = 'Show this help in language: {$a}';
$string['schedule'] = 'Schedule';
$string['sidepanel'] = 'Side panel';
$string['signoutofotherservices'] = 'Log out of all web apps';
$string['signoutofotherservices_help'] = 'Log out of all devices and systems that use web services, such as the mobile app. Browser sessions will remain active.';
$string['since'] = 'Since';
$string['sincelast'] = 'since last login';
$string['site'] = 'Site';
$string['sitedefault'] = 'Site default';
$string['sitedefaultspecified'] = 'Site default ({$a})';
$string['siteerrors'] = 'Site errors';
$string['sitefiles'] = 'Site files';
$string['sitefilesused'] = 'Site files used in this course';
$string['sitehome'] = 'Site home';
$string['sitelegacyfiles'] = 'Legacy site files';
$string['sitelogs'] = 'Site logs';
$string['sitenews'] = 'Site announcements';
$string['sitepages'] = 'Site pages';
$string['sitepartlist'] = 'You do not have the required permissions to view the participants list';
$string['sitepartlist0'] = 'You must be a site teacher to be allowed to see the site participants list';
$string['sitepartlist1'] = 'You must be a teacher to be allowed to see the site participants list';
$string['sites'] = 'Sites';
$string['sitesection'] = 'Add custom content';
$string['sitesettings'] = 'Site settings';
$string['siteteachers'] = 'Site teachers';
$string['size'] = 'Size';
$string['sizeb'] = 'bytes';
$string['sizegb'] = 'GB';
$string['sizekb'] = 'KB';
$string['sizemb'] = 'MB';
$string['sizepb'] = 'PB';
$string['sizetb'] = 'TB';
$string['skipped'] = 'Skipped';
$string['skiptocategorylisting'] = 'Skip to the category listings';
$string['skiptocourselisting'] = 'Skip to the course listings';
$string['skiptocoursedetails'] = 'Skip to the detailed course information';
$string['someallowguest'] = 'Some courses may allow guest access';
$string['someerrorswerefound'] = 'Some information was missing or incorrect. Look below for details.';
$string['sort'] = 'Sort';
$string['sortby'] = 'Sort by';
$string['sortbyx'] = 'Sort by {$a} ascending';
$string['sortbyxreverse'] = 'Sort by {$a} descending';
$string['sorting'] = 'Sorting';
$string['sourcerole'] = 'Source role';
$string['specifyname'] = 'You must specify a name.';
$string['standard'] = 'Standard';
$string['starpending'] = '([*] = course pending approval)';
$string['startdate'] = 'Course start date';
$string['startdate_help'] = 'This date determines the start of the first week for a course in weekly format. It is also the start date for logs of course activities.

If you reset the course and change this date, all dates in the course will be moved in relation to the new start date.';
$string['startdatewithtaskenabled'] = 'Course start date';
$string['startdatewithtaskenabled_help'] = 'The date when the course becomes visible to students. Before this date, they will not be able to access the course.

This date also determines the start of the first week for a course in weekly format, and is the start date for logs of course activities. if you reset the course and change this date, all dates in the course will be moved in relation to the new start date.';
$string['startingfrom'] = 'Starting from';
$string['startsignup'] = 'Create new account';
$string['state'] = 'State/Province';
$string['statistics'] = 'Statistics';
$string['statisticsgraph'] = 'Statistics graph';
$string['stats'] = 'Statistics';
$string['statslogins'] = 'Logins';
$string['statsmodedetailed'] = 'Detailed (user) view';
$string['statsmodegeneral'] = 'General view';
$string['statsnodata'] = 'There is no available data for that combination of course and time period.';
$string['statsnodatauser'] = 'There is no available data for that combination of course, user and time period.';
$string['statsoff'] = 'Statistics is not currently enabled';
$string['statsreads'] = 'Views';
$string['statsreportactivity'] = 'All activity (all roles)';
$string['statsreportactivitybyrole'] = 'All activity (views and posts)';
$string['statsreportforuser'] = 'for';
$string['statsreportlogins'] = 'Logins';
$string['statsreportreads'] = 'Views (all roles)';
$string['statsreporttype'] = 'Report type';
$string['statsreportwrites'] = 'Posts (all roles)';
$string['statsreport1'] = 'Logins';
$string['statsreport10'] = 'User activity';
$string['statsreport11'] = 'Most active courses';
$string['statsreport12'] = 'Most active courses (weighted)';
$string['statsreport13'] = 'Most participatory courses (enrolments)';
$string['statsreport14'] = 'Most participatory courses (posts/views)';
$string['statsreport2'] = 'Views (all roles)';
$string['statsreport3'] = 'Posts (all roles)';
$string['statsreport4'] = 'All activity (all roles)';
$string['statsreport5'] = 'All activity (views and posts)';
$string['statsreport7'] = 'User activity (views and posts)';
$string['statsreport8'] = 'All user activity';
$string['statsreport9'] = 'Logins (site course)';
$string['statsstudentactivity'] = 'Student activity';
$string['statsstudentreads'] = 'Student views';
$string['statsstudentwrites'] = 'Student posts';
$string['statsteacheractivity'] = 'Teacher activity';
$string['statsteacherreads'] = 'Teacher views';
$string['statsteacherwrites'] = 'Teacher posts';
$string['statstimeperiod'] = 'Time period - last:';
$string['statsuniquelogins'] = 'Unique logins';
$string['statsuseractivity'] = 'All activity';
$string['statsuserlogins'] = 'Logins';
$string['statsuserreads'] = 'Views';
$string['statsuserwrites'] = 'Posts';
$string['statswrites'] = 'Posts';
$string['status'] = 'Status';
$string['statuschecks'] = 'Status checks';
$string['statuscritical'] = 'Critical';
$string['statusdone'] = 'Done';
$string['statusinfo'] = 'Info';
$string['statusna'] = 'N/A';
$string['statusok'] = 'OK';
$string['statuserror'] = 'Error';
$string['statusunknown'] = 'Unknown';
$string['statuswarning'] = 'Warning';
$string['stringsnotset'] = 'The following strings are not defined in {$a}';
$string['studentnotallowed'] = 'Sorry, but you can not enter this course as \'{$a}\'';
$string['students'] = 'Students';
$string['studentsandteachers'] = 'Students and teachers';
$string['subcategories'] = 'Subcategories';
$string['subcategory'] = 'Subcategory';
$string['subcategoryof'] = 'Subcategory of {$a}';
$string['submit'] = 'Submit';
$string['subject'] = 'Subject';
$string['success'] = 'Success';
$string['successduration'] = 'Success ({$a} seconds)';
$string['summary'] = 'Summary';
$string['suspended'] = 'Suspended';
$string['suspendedusers'] = 'Suspended users';
$string['switchdevicedefault'] = 'Switch to the standard theme';
$string['switchdevicerecommended'] = 'Switch to the recommended theme for your device';
$string['switchrolereturn'] = 'Return to my normal role';
$string['switchroleto'] = 'Switch role to...';
$string['switchroleto_help'] = 'Choose a role to get an idea of how someone with that role will see this course.

Please note that this view may not be perfect (<a href="https://docs.moodle.org/en/Switch_roles">See details and alternatives</a>).';
$string['tag'] = 'Tag';
$string['tagalready'] = 'This tag already exists';
$string['tagmanagement'] = 'Add/delete tags ...';
$string['tags'] = 'Tags';
$string['targetrole'] = 'Target role';
$string['teacheronly'] = 'for the {$a} only';
$string['teacherroles'] = '{$a} roles';
$string['teachers'] = 'Teachers';
$string['textcopiedtoclipboard'] = 'Text copied to clipboard';
$string['textediting'] = 'Text editor';
$string['textediting_help'] = 'If an HTML editor such as Atto or TinyMCE is selected, text input areas will have a toolbar with buttons for easily adding content.

If \'plain text area\' is selected, a format for text input areas such as HTML or Markdown can be chosen.

The list of available text editors is determined by the site administrator.';
$string['texteditor'] = 'Use standard web forms';
$string['textformat'] = 'Plain text format';
$string['textellipsis'] = '{$a}...';
$string['timesplitting:deciles'] = 'Last tenth';
$string['timesplitting:deciles_help'] = 'This analysis interval divides the course into tenths (10 equal parts), with each prediction being based on the data of only the most recent previous tenth.';
$string['timesplitting:decilesaccum'] = 'All previous tenths';
$string['timesplitting:decilesaccum_help'] = 'This analysis interval divides the course into tenths (10 equal parts), with each prediction being based on the accumulated data of all previous tenths.';
$string['timesplitting:nosplitting'] = 'No time limits';
$string['timesplitting:nosplitting_help'] = 'No analysis interval is defined for this model.';
$string['timesplitting:quarters'] = 'Last quarter';
$string['timesplitting:quarters_help'] = 'This analysis interval divides the course into quarters (4 equal parts), with each prediction being based on the data of only the most recent previous quarter.';
$string['timesplitting:quartersaccum'] = 'All previous quarters';
$string['timesplitting:quartersaccum_help'] = 'This analysis interval divides the course into quarters (4 equal parts), with each prediction being based on the accumulated data of all previous quarters.';
$string['timesplitting:singlerange'] = 'From start to end';
$string['timesplitting:singlerange_help'] = 'This analysis interval considers the entire course as a single span.';
$string['timesplitting:onemonthafterstart'] = 'One month after start';
$string['timesplitting:onemonthafterstart_help'] = 'This analysis interval generates a prediction 1 month after the analysable start.';
$string['timesplitting:oneweekafterstart'] = 'One week after start';
$string['timesplitting:oneweekafterstart_help'] = 'This analysis interval generates a prediction 1 week after the analysable start.';
$string['timesplitting:past3days'] = 'Past 3 days';
$string['timesplitting:past3days_help'] = 'This analysis interval generates predictions every 3 days. The indicators calculations will be based on the past 3 days.';
$string['timesplitting:pastmonth'] = 'Past month';
$string['timesplitting:pastmonth_help'] = 'This analysis interval generates predictions every month. The indicators calculations will be based on the past month.';
$string['timesplitting:pastweek'] = 'Past week';
$string['timesplitting:pastweek_help'] = 'This analysis interval generates predictions every week. The indicators calculations will be based on the past week.';
$string['timesplitting:upcoming3days'] = 'Upcoming 3 days';
$string['timesplitting:upcoming3days_help'] = 'This analysis interval generates predictions every 3 days. The indicators calculations will be based on the upcoming 3 days.';
$string['timesplitting:upcomingfortnight'] = 'Upcoming fortnight';
$string['timesplitting:upcomingfortnight_help'] = 'This analysis interval generates predictions every fortnight. The indicators calculations will be based on the upcoming fortnight.';
$string['timesplitting:upcomingweek'] = 'Upcoming week';
$string['timesplitting:upcomingweek_help'] = 'This analysis interval generates predictions every week. The indicators calculations will be based on the upcoming week.';
$string['timesplitting:tenpercentafterstart'] = '10% after start';
$string['timesplitting:tenpercentafterstart_help'] = 'This analysis interval generates a prediction after the 10% of the course is completed.';
$string['thanks'] = 'Thanks';
$string['theme'] = 'Theme';
$string['themepreviewdescription'] = '{$a} theme description';
$string['themepreviewimage'] = '{$a} preview image';
$string['themes'] = 'Themes';
$string['themesaved'] = 'New theme saved';
$string['thereareno'] = 'There are no {$a} in this course';
$string['therearecourses'] = 'There are {$a} courses';
$string['thiscategory'] = 'This category';
$string['thiscategorycontains'] = 'This category contains';
$string['time'] = 'Time';
$string['timecreated'] = 'Time created';
$string['timecreatedcourse'] = 'Course time created';
$string['timezone'] = 'Timezone';
$string['todate'] = 'To';
$string['torecipient'] = 'To';
$string['tocreatenewaccount'] = 'Skip to create new account';
$string['tocontent'] = 'To item "{$a}"';
$string['today'] = 'Today';
$string['todaylogs'] = 'Today\'s logs';
$string['toeveryone'] = 'to everyone';
$string['toggleemojipicker'] = 'Toggle emoji picker';
$string['togglesearch'] = 'Toggle search input';
$string['toomanybounces'] = 'That email address has had too many bounces. You <b>must</b> change it to continue.';
$string['toomanytags'] = 'This search included too many tags; some will have been ignored.';
$string['toomanytoshow'] = 'There are too many users to show.';
$string['toomanyusersmatchsearch'] = 'Too many users ({$a->count}) match \'{$a->search}\'';
$string['toomanyuserstoshow'] = 'Too many users ({$a}) to show';
$string['toonly'] = 'to {$a} only';
$string['top'] = 'Top';
$string['toplevelcategory'] = 'Top level category';
$string['topic'] = 'Topic';
$string['total'] = 'Total';
$string['totopofsection'] = 'To the top of section "{$a}"';
$string['trackforums'] = 'Forum tracking';
$string['trackforumsno'] = 'No: don\'t keep track of posts I have seen';
$string['trackforumsyes'] = 'Yes: highlight new posts for me';
$string['trysearching'] = 'Try searching instead.';
$string['turneditingoff'] = 'Turn editing off';
$string['turneditingon'] = 'Turn editing on';
$string['unauthorisedlogin'] = 'The user account "{$a}" is not available on this site';
$string['unabletocopytoclipboard'] = 'Unable to copy text to the clipboard';
$string['undecided'] = 'Undecided';
$string['unexistingcmid'] = 'Course module ID not found';
$string['unexistingsectionid'] = 'Course section ID not found';
$string['unfinished'] = 'Unfinished';
$string['unknowncategory'] = 'Unknown category';
$string['unknownerror'] = 'Unknown error';
$string['unknownuser'] = 'Unknown user';
$string['unlimited'] = 'Unlimited';
$string['unpacking'] = 'Unpacking {$a}';
$string['unsafepassword'] = 'Unsafe password - try something else';
$string['untilcomplete'] = 'Until complete';
$string['unusedaccounts'] = 'Accounts unused for more than {$a} days are automatically unenrolled';
$string['unzip'] = 'Unzip';
$string['unzippingbackup'] = 'Unzipping backup';
$string['up'] = 'Up';
$string['update'] = 'Update';
$string['updated'] = 'Updated {$a}';
$string['updatemymoodleoff'] = 'Stop customising this page';
$string['updatemymoodleon'] = 'Customise this page';
$string['updatemyprofile'] = 'Update profile';
$string['updatesevery'] = 'Updates every {$a} seconds';
$string['updatethis'] = 'Update this {$a}';
$string['updatethiscourse'] = 'Update this course';
$string['upload'] = 'Upload';
$string['uploadafile'] = 'Upload a file';
$string['uploadcantwrite'] = 'Failed to write file to disk';
$string['uploadedfile'] = 'File uploaded successfully';
$string['uploadedfileto'] = 'Uploaded {$a->file} to {$a->directory}';
$string['uploadedfiletoobig'] = 'Sorry, but that file is too big (limit is {$a} bytes)';
$string['uploadextension'] = 'File upload stopped by a PHP extension';
$string['uploadfailednotrecovering'] = 'Your file upload has failed because there was a problem with one of the files, {$a->name}.<br /> Here is a log of the problems:<br />{$a->problem}<br />Not recovering.';
$string['uploadfilelog'] = 'Upload log for file {$a}';
$string['uploadformlimit'] = 'Uploaded file {$a} exceeded the maximum size limit set by the form';
$string['uploadlabel'] = 'Title:';
$string['uploadlimitwithsize'] = '{$a->contextname} upload limit ({$a->displaysize})';
$string['uploadnewfile'] = 'Upload new file';
$string['uploadnofilefound'] = 'No file was found - are you sure you selected one to upload?';
$string['uploadnotallowed'] = 'Uploads are not allowed';
$string['uploadnotempdir'] = 'Missing a temporary folder';
$string['uploadoldfilesdeleted'] = 'The old file(s) in your upload area have been deleted';
$string['uploadpartialfile'] = 'File was only partially uploaded';
$string['uploadproblem'] = 'An unknown problem occurred while uploading the file \'{$a}\' (perhaps it was too large?)';
$string['uploadrenamedcollision'] = 'File was renamed from {$a->oldname} to {$a->newname} because there was a filename conflict.';
$string['uploadrenamedchars'] = 'File was renamed from {$a->oldname} to {$a->newname} because of invalid characters.';
$string['uploadserverlimit'] = 'Uploaded file exceeded the maximum size limit set by the server';
$string['uploadthisfile'] = 'Upload this file';
$string['url'] = 'URL';
$string['used'] = 'Used';
$string['usedinnplaces'] = 'Used in {$a} places';
$string['user'] = 'User';
$string['useraccount'] = 'User account';
$string['userconfirmed'] = 'Confirmed {$a}';
$string['useractivity'] = 'Activity';
$string['userdata'] = 'User data';
$string['userdeleted'] = 'This user account has been deleted';
$string['userdescription'] = 'Description';
$string['userdescription_help'] = 'This box enables you to enter some text about yourself which will then be displayed on your profile page for others to view.';
$string['userdetails'] = 'User details';
$string['userfiles'] = 'User files';
$string['userlist'] = 'User list';
$string['usermatchedon'] = 'This user matches the search via the following field';
$string['usermenu'] = 'User menu';
$string['usermenugoback'] = 'Go back to user menu';
$string['username'] = 'Username';
$string['usernameemail'] = 'Username or email';
$string['usernameemailmatch'] = 'The username and email address do not relate to the same user';
$string['usernameexists'] = 'This username already exists, choose another';
$string['usernamelowercase'] = 'Only lowercase letters allowed';
$string['usernamenotfound'] = 'The username was not found in the database';
$string['usernameoremail'] = 'Enter either username or email address';
$string['usernotconfirmed'] = 'Could not confirm {$a}';
$string['userpic'] = 'User picture';
$string['users'] = 'Users';
$string['userselectorautoselectunique'] = 'If only one user matches the search, select them automatically';
$string['userselectorpreserveselected'] = 'Keep selected users, even if they no longer match the search';
$string['userselectorsearchmatching'] = 'Matching:';
$string['userselectorsearchfromstart'] = 'from start';
$string['userselectorsearchanywhere'] = 'anywhere';
$string['userselectorsearchexactmatchonly'] = 'exact matches only';
$string['usersnew'] = 'New users';
$string['usersnoaccesssince'] = 'Inactive for more than';
$string['userpreferences'] = 'User preferences';
$string['userswithfiles'] = 'Users with files';
$string['useruploadtype'] = 'User upload type: {$a}';
$string['userzones'] = 'User zones';
$string['usetheme'] = 'Use theme';
$string['usingexistingcourse'] = 'Using existing course';
$string['validatehtml'] = 'Validate HTML';
$string['valuealreadyused'] = 'This value has already been used.';
$string['version'] = 'Version';
$string['view'] = 'View';
$string['viewing'] = 'Viewing:';
$string['viewallcourses'] = 'View all courses';
$string['viewallcoursescategories'] = 'View all courses and categories';
$string['viewallresults'] = 'View all results ({$a})';
$string['viewmore'] = 'View more';
$string['viewallsubcategories'] = 'View all subcategories';
$string['viewfileinpopup'] = 'View file in a popup window';
$string['viewprofile'] = 'View profile';
$string['views'] = 'Views';
$string['viewsolution'] = 'view solution';
$string['visible'] = 'Visible';
$string['visible_help'] = 'This setting determines whether the course appears in the list of courses. Apart from teachers and administrators, users are not allowed to enter the course.';
$string['visibletostudents'] = 'Visible to {$a}';
$string['wcagcheck'] = 'Web Content Accessibility Guidelines (WCAG) check';
$string['warning'] = 'Warning';
$string['warningdeleteresource'] = 'Warning: {$a} is referred in a resource. Would you like to update the resource?';
$string['webpage'] = 'Web page';
$string['week'] = 'Week';
$string['weeks'] = 'weeks';
$string['welcomeback'] = 'Hi, {$a->firstname}! 👋';
$string['welcometosite'] = 'Welcome, {$a->firstname}! 👋';
$string['welcometocourse'] = 'Welcome to {$a}';
$string['welcometocoursetext'] = 'Welcome to {$a->coursename}!

If you have not done so already, you should edit your profile page so that we can learn more about you:

<a href="{$a->profileurl}">{$a->profileurl}</a>';
$string['whatforlink'] = 'What do you want to do with the link?';
$string['whatforpage'] = 'What do you want to do with the text?';
$string['whatisyourage'] = 'What is your age?';
$string['whattocallzip'] = 'What do you want to call the zip file?';
$string['whattodo'] = 'What to do';
$string['wheredoyoulive'] = 'In which country do you live?';
$string['whyisthisrequired'] = 'Why is this required?';
$string['windowclosing'] = 'This window should close automatically. If not, please close it now.';
$string['withchosenfiles'] = 'With chosen files';
$string['withdisablednote'] = '{$a} (disabled)';
$string['withoutuserdata'] = 'without user data';
$string['withselectedusers'] = 'With selected users...';
$string['withuserdata'] = 'with user data';
$string['wontrunfuturescheduledtask'] = "Won't run task that hasn't failed and is scheduled to run in the future";
$string['wordforstudent'] = 'Your word for Student';
$string['wordforstudenteg'] = 'eg Student, Participant etc';
$string['wordforstudents'] = 'Your word for Students';
$string['wordforstudentseg'] = 'eg Students, Participants etc';
$string['wordforteacher'] = 'Your word for Teacher';
$string['wordforteachereg'] = 'eg Teacher, Tutor, Facilitator etc';
$string['wordforteachers'] = 'Your word for Teachers';
$string['wordforteacherseg'] = 'eg Teachers, Tutors, Facilitators etc';
$string['writingblogsinfo'] = 'Writing blogs info';
$string['writingcategoriesandquestions'] = 'Writing categories and questions';
$string['writingcoursedata'] = 'Writing course data';
$string['writingeventsinfo'] = 'Writing events info';
$string['writinggeneralinfo'] = 'Writing general info';
$string['writinggradebookinfo'] = 'Writing gradebook info';
$string['writinggroupingsgroupsinfo'] = 'Writing groupings-groups info';
$string['writinggroupingsinfo'] = 'Writing groupings info';
$string['writinggroupsinfo'] = 'Writing groups info';
$string['writingheader'] = 'Writing header';
$string['writingloginfo'] = 'Writing logs info';
$string['writingmessagesinfo'] = 'Writing messages info';
$string['writingmoduleinfo'] = 'Writing modules info';
$string['writingscalesinfo'] = 'Writing scales info';
$string['writinguserinfo'] = 'Writing users info';
$string['wrongpassword'] = 'Incorrect password for this username';
$string['year'] = 'year';
$string['years'] = 'years';
$string['yes'] = 'Yes';
$string['youareabouttocreatezip'] = 'You are about to create a zip file containing';
$string['youaregoingtorestorefrom'] = 'You are about to start the restore process for';
$string['youhaveupcomingactivitiesdue'] = 'You have upcoming activities due';
$string['youhaveupcomingactivitiesdueinfo'] = 'Hi {$a},

<br/><br/>You have upcoming activities due:';
$string['youneedtoenrol'] = 'To perform that action you need to enrol in this course.';
$string['yourlastlogin'] = 'Your last login was';
$string['yourself'] = 'yourself';
$string['yourteacher'] = 'your {$a}';
$string['yourwordforx'] = 'Your word for \'{$a}\'';
$string['zippingbackup'] = 'Zipping backup';
$string['deprecatedeventname'] = '{$a} (no longer in use)';

// Deprecated since Moodle 4.5.
$string['commentscount'] = 'Comments ({$a})';
$string['datechanged'] = 'Date changed';
$string['newpasswordtext'] = 'Hi {$a->firstname},

Your account password at \'{$a->sitename}\' has been reset
and you have been issued with a new temporary password.

Your current login information is now:
   username: {$a->username}
   password: {$a->newpassword}

Please go to this page to change your password:
   {$a->link}

In most mail programs, this should appear as a blue link
which you can just click on.  If that doesn\'t work,
then cut and paste the address into the address
line at the top of your web browser window.

Cheers from the \'{$a->sitename}\' administrator,
{$a->signoff}';
$string['noreplybouncemessage'] = 'You have replied to a no-reply email address. If you were attempting to reply to a forum post, please instead reply using the {$a} forums.

Following is the content of your email:';
$string['noreplybouncesubject'] = '{$a} - bounced email.';
$string['registrationcontactno'] = 'No, I do not want to be contacted by other people';
$string['registrationcontactyes'] = 'Yes, provide a form for other Moodlers to contact me';

// Deprecated since Moodle 5.0.
$string['failedtaskcontexturlname'] = 'Status report';

// Deprecated since Moodle 5.1.
$string['activities_help'] = 'Activities, such as forums, quizzes and wikis, enable interactive content to be added to the course.';
$string['hiddensections_help'] = 'Hidden sections can be displayed to students as \'not available\' on the course page, or kept completely hidden.';
$string['maxsectionslimit'] = 'Cannot create new section as it would exceed the maximum number of sections allowed for this course ({$a}).';
$string['resources_help'] = 'Resource types enable almost any kind of web content to be inserted into the course.';
